/********************************************************************************
** Form generated from reading UI file 'sizedialogwidgetbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SIZEDIALOGWIDGETBASE_H
#define UI_SIZEDIALOGWIDGETBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "gui/formattedspinbox.h"
#include "gui/partresizerwidget.h"
#include "knewpasswordwidget.h"

QT_BEGIN_NAMESPACE

class Ui_SizeDialogWidgetBase
{
public:
    QGridLayout *gridLayout;
    QLabel *label_4;
    KNewPasswordWidget *m_EditPassphrase;
    QLabel *m_LabelMinSize;
    PartResizerWidget *m_PartResizerWidget;
    QLabel *label_5;
    QSpacerItem *verticalSpacer_2;
    QLabel *m_LabelTextLabel;
    FormattedSpinBox *m_SpinCapacity;
    QVBoxLayout *verticalLayout;
    QLineEdit *m_EditLabel;
    QLabel *m_LabelTextNoSetLabel;
    QSpacerItem *verticalSpacer;
    QLabel *label_2;
    QVBoxLayout *verticalLayout_2;
    QComboBox *m_ComboFileSystem;
    QGroupBox *m_groupBox_type;
    QHBoxLayout *horizontalLayout;
    QRadioButton *m_RadioPrimary;
    QRadioButton *m_RadioExtended;
    QRadioButton *m_RadioLogical;
    QLabel *m_LabelFileSystem;
    FormattedSpinBox *m_SpinFreeAfter;
    QLineEdit *m_EditLVName;
    QLabel *m_LabelRole;
    QCheckBox *m_CheckBoxEncrypt;
    QLabel *m_LabelMaxSize;
    FormattedSpinBox *m_SpinFreeBefore;
    QLabel *m_labelPermission;
    QGroupBox *m_groupBox_permissions;
    QVBoxLayout *verticalLayout_3;
    QRadioButton *m_permissionEveryone;
    QRadioButton *m_permissionOnlyRoot;
    QLabel *m_LabelFreeBefore;
    QLabel *m_LabelTextLVName;
    QLabel *m_LabelFreeAfter;
    QCheckBox *m_CheckBoxLuks2;

    void setupUi(QWidget *SizeDialogWidgetBase)
    {
        if (SizeDialogWidgetBase->objectName().isEmpty())
            SizeDialogWidgetBase->setObjectName("SizeDialogWidgetBase");
        SizeDialogWidgetBase->resize(653, 814);
        gridLayout = new QGridLayout(SizeDialogWidgetBase);
        gridLayout->setObjectName("gridLayout");
        label_4 = new QLabel(SizeDialogWidgetBase);
        label_4->setObjectName("label_4");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_4->sizePolicy().hasHeightForWidth());
        label_4->setSizePolicy(sizePolicy);
        label_4->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_4, 9, 0, 1, 1);

        m_EditPassphrase = new KNewPasswordWidget(SizeDialogWidgetBase);
        m_EditPassphrase->setObjectName("m_EditPassphrase");

        gridLayout->addWidget(m_EditPassphrase, 6, 0, 1, 2);

        m_LabelMinSize = new QLabel(SizeDialogWidgetBase);
        m_LabelMinSize->setObjectName("m_LabelMinSize");
        m_LabelMinSize->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByKeyboard|Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout->addWidget(m_LabelMinSize, 9, 1, 1, 1);

        m_PartResizerWidget = new PartResizerWidget(SizeDialogWidgetBase);
        m_PartResizerWidget->setObjectName("m_PartResizerWidget");
        m_PartResizerWidget->setMinimumSize(QSize(400, 60));
        m_PartResizerWidget->setMaximumSize(QSize(16777215, 60));

        gridLayout->addWidget(m_PartResizerWidget, 0, 0, 1, 2);

        label_5 = new QLabel(SizeDialogWidgetBase);
        label_5->setObjectName("label_5");
        sizePolicy.setHeightForWidth(label_5->sizePolicy().hasHeightForWidth());
        label_5->setSizePolicy(sizePolicy);
        label_5->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_5, 10, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(470, 7, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_2, 15, 0, 1, 2);

        m_LabelTextLabel = new QLabel(SizeDialogWidgetBase);
        m_LabelTextLabel->setObjectName("m_LabelTextLabel");
        m_LabelTextLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(m_LabelTextLabel, 8, 0, 1, 1);

        m_SpinCapacity = new FormattedSpinBox(SizeDialogWidgetBase);
        m_SpinCapacity->setObjectName("m_SpinCapacity");
        m_SpinCapacity->setMinimum(0.000000000000000);
        m_SpinCapacity->setMaximum(999999999.000000000000000);

        gridLayout->addWidget(m_SpinCapacity, 12, 1, 1, 1);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        m_EditLabel = new QLineEdit(SizeDialogWidgetBase);
        m_EditLabel->setObjectName("m_EditLabel");

        verticalLayout->addWidget(m_EditLabel);

        m_LabelTextNoSetLabel = new QLabel(SizeDialogWidgetBase);
        m_LabelTextNoSetLabel->setObjectName("m_LabelTextNoSetLabel");
        m_LabelTextNoSetLabel->setWordWrap(true);

        verticalLayout->addWidget(m_LabelTextNoSetLabel);


        gridLayout->addLayout(verticalLayout, 8, 1, 1, 1);

        verticalSpacer = new QSpacerItem(470, 17, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer, 1, 0, 1, 2);

        label_2 = new QLabel(SizeDialogWidgetBase);
        label_2->setObjectName("label_2");
        sizePolicy.setHeightForWidth(label_2->sizePolicy().hasHeightForWidth());
        label_2->setSizePolicy(sizePolicy);
        label_2->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_2, 12, 0, 1, 1);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        m_ComboFileSystem = new QComboBox(SizeDialogWidgetBase);
        m_ComboFileSystem->setObjectName("m_ComboFileSystem");

        verticalLayout_2->addWidget(m_ComboFileSystem);


        gridLayout->addLayout(verticalLayout_2, 3, 1, 1, 1);

        m_groupBox_type = new QGroupBox(SizeDialogWidgetBase);
        m_groupBox_type->setObjectName("m_groupBox_type");
        horizontalLayout = new QHBoxLayout(m_groupBox_type);
        horizontalLayout->setObjectName("horizontalLayout");
        m_RadioPrimary = new QRadioButton(m_groupBox_type);
        m_RadioPrimary->setObjectName("m_RadioPrimary");

        horizontalLayout->addWidget(m_RadioPrimary);

        m_RadioExtended = new QRadioButton(m_groupBox_type);
        m_RadioExtended->setObjectName("m_RadioExtended");

        horizontalLayout->addWidget(m_RadioExtended);

        m_RadioLogical = new QRadioButton(m_groupBox_type);
        m_RadioLogical->setObjectName("m_RadioLogical");

        horizontalLayout->addWidget(m_RadioLogical);


        gridLayout->addWidget(m_groupBox_type, 2, 1, 1, 1);

        m_LabelFileSystem = new QLabel(SizeDialogWidgetBase);
        m_LabelFileSystem->setObjectName("m_LabelFileSystem");
        sizePolicy.setHeightForWidth(m_LabelFileSystem->sizePolicy().hasHeightForWidth());
        m_LabelFileSystem->setSizePolicy(sizePolicy);
        m_LabelFileSystem->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(m_LabelFileSystem, 3, 0, 1, 1);

        m_SpinFreeAfter = new FormattedSpinBox(SizeDialogWidgetBase);
        m_SpinFreeAfter->setObjectName("m_SpinFreeAfter");
        m_SpinFreeAfter->setMinimum(0.000000000000000);
        m_SpinFreeAfter->setMaximum(999999999.000000000000000);

        gridLayout->addWidget(m_SpinFreeAfter, 13, 1, 1, 1);

        m_EditLVName = new QLineEdit(SizeDialogWidgetBase);
        m_EditLVName->setObjectName("m_EditLVName");
        m_EditLVName->setEnabled(true);

        gridLayout->addWidget(m_EditLVName, 7, 1, 1, 1);

        m_LabelRole = new QLabel(SizeDialogWidgetBase);
        m_LabelRole->setObjectName("m_LabelRole");
        sizePolicy.setHeightForWidth(m_LabelRole->sizePolicy().hasHeightForWidth());
        m_LabelRole->setSizePolicy(sizePolicy);
        m_LabelRole->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(m_LabelRole, 2, 0, 1, 1);

        m_CheckBoxEncrypt = new QCheckBox(SizeDialogWidgetBase);
        m_CheckBoxEncrypt->setObjectName("m_CheckBoxEncrypt");

        gridLayout->addWidget(m_CheckBoxEncrypt, 4, 1, 1, 1);

        m_LabelMaxSize = new QLabel(SizeDialogWidgetBase);
        m_LabelMaxSize->setObjectName("m_LabelMaxSize");
        m_LabelMaxSize->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByKeyboard|Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout->addWidget(m_LabelMaxSize, 10, 1, 1, 1);

        m_SpinFreeBefore = new FormattedSpinBox(SizeDialogWidgetBase);
        m_SpinFreeBefore->setObjectName("m_SpinFreeBefore");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(4);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(m_SpinFreeBefore->sizePolicy().hasHeightForWidth());
        m_SpinFreeBefore->setSizePolicy(sizePolicy1);
        m_SpinFreeBefore->setMinimum(0.000000000000000);
        m_SpinFreeBefore->setMaximum(999999999.000000000000000);

        gridLayout->addWidget(m_SpinFreeBefore, 11, 1, 1, 1);

        m_labelPermission = new QLabel(SizeDialogWidgetBase);
        m_labelPermission->setObjectName("m_labelPermission");
        m_labelPermission->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(m_labelPermission, 14, 0, 1, 1);

        m_groupBox_permissions = new QGroupBox(SizeDialogWidgetBase);
        m_groupBox_permissions->setObjectName("m_groupBox_permissions");
        verticalLayout_3 = new QVBoxLayout(m_groupBox_permissions);
        verticalLayout_3->setObjectName("verticalLayout_3");
        m_permissionEveryone = new QRadioButton(m_groupBox_permissions);
        m_permissionEveryone->setObjectName("m_permissionEveryone");

        verticalLayout_3->addWidget(m_permissionEveryone);

        m_permissionOnlyRoot = new QRadioButton(m_groupBox_permissions);
        m_permissionOnlyRoot->setObjectName("m_permissionOnlyRoot");

        verticalLayout_3->addWidget(m_permissionOnlyRoot);


        gridLayout->addWidget(m_groupBox_permissions, 14, 1, 1, 1);

        m_LabelFreeBefore = new QLabel(SizeDialogWidgetBase);
        m_LabelFreeBefore->setObjectName("m_LabelFreeBefore");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy2.setHorizontalStretch(3);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(m_LabelFreeBefore->sizePolicy().hasHeightForWidth());
        m_LabelFreeBefore->setSizePolicy(sizePolicy2);
        m_LabelFreeBefore->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(m_LabelFreeBefore, 11, 0, 1, 1);

        m_LabelTextLVName = new QLabel(SizeDialogWidgetBase);
        m_LabelTextLVName->setObjectName("m_LabelTextLVName");
        m_LabelTextLVName->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(m_LabelTextLVName, 7, 0, 1, 1);

        m_LabelFreeAfter = new QLabel(SizeDialogWidgetBase);
        m_LabelFreeAfter->setObjectName("m_LabelFreeAfter");
        sizePolicy.setHeightForWidth(m_LabelFreeAfter->sizePolicy().hasHeightForWidth());
        m_LabelFreeAfter->setSizePolicy(sizePolicy);
        m_LabelFreeAfter->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(m_LabelFreeAfter, 13, 0, 1, 1);

        m_CheckBoxLuks2 = new QCheckBox(SizeDialogWidgetBase);
        m_CheckBoxLuks2->setObjectName("m_CheckBoxLuks2");

        gridLayout->addWidget(m_CheckBoxLuks2, 5, 1, 1, 1);

#if QT_CONFIG(shortcut)
        m_LabelTextLabel->setBuddy(m_EditLabel);
        label_2->setBuddy(m_SpinCapacity);
        m_LabelFileSystem->setBuddy(m_ComboFileSystem);
        m_LabelFreeBefore->setBuddy(m_SpinFreeBefore);
        m_LabelFreeAfter->setBuddy(m_SpinFreeAfter);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(m_RadioPrimary, m_RadioExtended);
        QWidget::setTabOrder(m_RadioExtended, m_RadioLogical);
        QWidget::setTabOrder(m_RadioLogical, m_ComboFileSystem);
        QWidget::setTabOrder(m_ComboFileSystem, m_CheckBoxEncrypt);
        QWidget::setTabOrder(m_CheckBoxEncrypt, m_CheckBoxLuks2);
        QWidget::setTabOrder(m_CheckBoxLuks2, m_EditLVName);
        QWidget::setTabOrder(m_EditLVName, m_EditLabel);
        QWidget::setTabOrder(m_EditLabel, m_SpinFreeBefore);
        QWidget::setTabOrder(m_SpinFreeBefore, m_SpinCapacity);
        QWidget::setTabOrder(m_SpinCapacity, m_SpinFreeAfter);
        QWidget::setTabOrder(m_SpinFreeAfter, m_permissionEveryone);
        QWidget::setTabOrder(m_permissionEveryone, m_permissionOnlyRoot);

        retranslateUi(SizeDialogWidgetBase);

        QMetaObject::connectSlotsByName(SizeDialogWidgetBase);
    } // setupUi

    void retranslateUi(QWidget *SizeDialogWidgetBase)
    {
        label_4->setText(tr2i18n("Minimum size:", "@label"));
        label_5->setText(tr2i18n("Maximum size:", "@label"));
        m_LabelTextLabel->setText(tr2i18n("Label:", "@label"));
        m_LabelTextNoSetLabel->setText(tr2i18n("This file system does not support setting a label.", "@label"));
        label_2->setText(tr2i18n("Si&ze:", "@label:listbox"));
        m_RadioPrimary->setText(tr2i18n("Primar&y", nullptr));
        m_RadioExtended->setText(tr2i18n("E&xtended", nullptr));
        m_RadioLogical->setText(tr2i18n("&Logical", nullptr));
        m_LabelFileSystem->setText(tr2i18n("File system:", "@label:listbox"));
        m_LabelRole->setText(tr2i18n("Partition type:", "@label:listbox"));
#if QT_CONFIG(tooltip)
        m_CheckBoxEncrypt->setToolTip(tr2i18n("Set up encryption for this filesystem with LUKS. You will be asked to provide a passphrase.", nullptr));
#endif // QT_CONFIG(tooltip)
        m_CheckBoxEncrypt->setText(tr2i18n("Encrypt with LUKS", nullptr));
        m_labelPermission->setText(tr2i18n("Permissions", nullptr));
#if QT_CONFIG(tooltip)
        m_permissionEveryone->setToolTip(tr2i18n("Allow everyone to write and read on this device", nullptr));
#endif // QT_CONFIG(tooltip)
        m_permissionEveryone->setText(tr2i18n("Everyone", nullptr));
#if QT_CONFIG(tooltip)
        m_permissionOnlyRoot->setToolTip(tr2i18n("Allow only root to write and read on this device, you will need to setup per-folder permissions", nullptr));
#endif // QT_CONFIG(tooltip)
        m_permissionOnlyRoot->setText(tr2i18n("O&nly Root", nullptr));
        m_LabelFreeBefore->setText(tr2i18n("F&ree space before:", "@label:listbox"));
        m_LabelTextLVName->setText(tr2i18n("Logical Volume Name:", nullptr));
        m_LabelFreeAfter->setText(tr2i18n("Free space after:", "@label:listbox"));
#if QT_CONFIG(tooltip)
        m_CheckBoxLuks2->setToolTip(tr2i18n("Use LUKS2 instead of LUKS1 for better security, but compatibility may be compromised.", nullptr));
#endif // QT_CONFIG(tooltip)
        m_CheckBoxLuks2->setText(tr2i18n("Enable LUKS2", nullptr));
        (void)SizeDialogWidgetBase;
    } // retranslateUi

};

namespace Ui {
    class SizeDialogWidgetBase: public Ui_SizeDialogWidgetBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SIZEDIALOGWIDGETBASE_H

