/********************************************************************************
** Form generated from reading UI file 'editmountoptionsdialogwidgetbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EDITMOUNTOPTIONSDIALOGWIDGETBASE_H
#define UI_EDITMOUNTOPTIONSDIALOGWIDGETBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_EditMountOptionsDialogWidgetBase
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *m_Label;
    QPlainTextEdit *m_EditOptions;

    void setupUi(QWidget *EditMountOptionsDialogWidgetBase)
    {
        if (EditMountOptionsDialogWidgetBase->objectName().isEmpty())
            EditMountOptionsDialogWidgetBase->setObjectName("EditMountOptionsDialogWidgetBase");
        EditMountOptionsDialogWidgetBase->resize(461, 261);
        verticalLayout = new QVBoxLayout(EditMountOptionsDialogWidgetBase);
        verticalLayout->setObjectName("verticalLayout");
        m_Label = new QLabel(EditMountOptionsDialogWidgetBase);
        m_Label->setObjectName("m_Label");

        verticalLayout->addWidget(m_Label);

        m_EditOptions = new QPlainTextEdit(EditMountOptionsDialogWidgetBase);
        m_EditOptions->setObjectName("m_EditOptions");

        verticalLayout->addWidget(m_EditOptions);


        retranslateUi(EditMountOptionsDialogWidgetBase);

        QMetaObject::connectSlotsByName(EditMountOptionsDialogWidgetBase);
    } // setupUi

    void retranslateUi(QWidget *EditMountOptionsDialogWidgetBase)
    {
        EditMountOptionsDialogWidgetBase->setWindowTitle(tr2i18n("Edit Mount Options", nullptr));
        m_Label->setText(tr2i18n("Edit the mount options for this file system:", nullptr));
        m_EditOptions->setPlaceholderText(tr2i18n("Option1,Option2", nullptr));
    } // retranslateUi

};

namespace Ui {
    class EditMountOptionsDialogWidgetBase: public Ui_EditMountOptionsDialogWidgetBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EDITMOUNTOPTIONSDIALOGWIDGETBASE_H

