/********************************************************************************
** Form generated from reading UI file 'smartdialogwidgetbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SMARTDIALOGWIDGETBASE_H
#define UI_SMARTDIALOGWIDGETBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SmartDialogWidgetBase
{
public:
    QGridLayout *gridLayout;
    QLabel *m_LabelTextSmartStatus;
    QHBoxLayout *horizontalLayout;
    QLabel *m_LabelSmartStatusIcon;
    QLabel *m_LabelSmartStatusText;
    QLabel *m_LabelTextSmartModelName;
    QLabel *m_LabelSmartModelName;
    QLabel *m_LabelTextSmartSerialNumber;
    QLabel *m_LabelSmartSerialNumber;
    QLabel *m_LabelTextSmartFirmware;
    QLabel *m_LabelSmartFirmware;
    QLabel *m_LabelTextSmartTemperature;
    QLabel *m_LabelSmartTemperature;
    QLabel *m_LabelTextSmartBadSectors;
    QLabel *m_LabelSmartBadSectors;
    QLabel *m_LabelTextSmartPoweredOn;
    QLabel *m_LabelSmartPoweredOn;
    QLabel *m_LabelTextSmartPowerCycles;
    QLabel *m_LabelSmartPowerCycles;
    QSpacerItem *verticalSpacer_3;
    QTreeWidget *m_TreeSmartAttributes;
    QSpacerItem *verticalSpacer_2;
    QFrame *line;
    QFrame *line_2;
    QLabel *m_LabelTextSmartOverallAssessment;
    QLabel *m_LabelSmartOverallAssessment;
    QLabel *m_LabelTextSmartSelfTests;
    QLabel *m_LabelSmartSelfTests;

    void setupUi(QWidget *SmartDialogWidgetBase)
    {
        if (SmartDialogWidgetBase->objectName().isEmpty())
            SmartDialogWidgetBase->setObjectName("SmartDialogWidgetBase");
        SmartDialogWidgetBase->resize(750, 550);
        gridLayout = new QGridLayout(SmartDialogWidgetBase);
        gridLayout->setObjectName("gridLayout");
        m_LabelTextSmartStatus = new QLabel(SmartDialogWidgetBase);
        m_LabelTextSmartStatus->setObjectName("m_LabelTextSmartStatus");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(2);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_LabelTextSmartStatus->sizePolicy().hasHeightForWidth());
        m_LabelTextSmartStatus->setSizePolicy(sizePolicy);
        m_LabelTextSmartStatus->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(m_LabelTextSmartStatus, 0, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        m_LabelSmartStatusIcon = new QLabel(SmartDialogWidgetBase);
        m_LabelSmartStatusIcon->setObjectName("m_LabelSmartStatusIcon");
        m_LabelSmartStatusIcon->setMaximumSize(QSize(16, 16777215));

        horizontalLayout->addWidget(m_LabelSmartStatusIcon);

        m_LabelSmartStatusText = new QLabel(SmartDialogWidgetBase);
        m_LabelSmartStatusText->setObjectName("m_LabelSmartStatusText");

        horizontalLayout->addWidget(m_LabelSmartStatusText);


        gridLayout->addLayout(horizontalLayout, 0, 1, 1, 2);

        m_LabelTextSmartModelName = new QLabel(SmartDialogWidgetBase);
        m_LabelTextSmartModelName->setObjectName("m_LabelTextSmartModelName");
        sizePolicy.setHeightForWidth(m_LabelTextSmartModelName->sizePolicy().hasHeightForWidth());
        m_LabelTextSmartModelName->setSizePolicy(sizePolicy);
        m_LabelTextSmartModelName->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(m_LabelTextSmartModelName, 3, 0, 1, 1);

        m_LabelSmartModelName = new QLabel(SmartDialogWidgetBase);
        m_LabelSmartModelName->setObjectName("m_LabelSmartModelName");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(3);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(m_LabelSmartModelName->sizePolicy().hasHeightForWidth());
        m_LabelSmartModelName->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(m_LabelSmartModelName, 3, 1, 1, 2);

        m_LabelTextSmartSerialNumber = new QLabel(SmartDialogWidgetBase);
        m_LabelTextSmartSerialNumber->setObjectName("m_LabelTextSmartSerialNumber");
        sizePolicy.setHeightForWidth(m_LabelTextSmartSerialNumber->sizePolicy().hasHeightForWidth());
        m_LabelTextSmartSerialNumber->setSizePolicy(sizePolicy);
        m_LabelTextSmartSerialNumber->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(m_LabelTextSmartSerialNumber, 4, 0, 1, 1);

        m_LabelSmartSerialNumber = new QLabel(SmartDialogWidgetBase);
        m_LabelSmartSerialNumber->setObjectName("m_LabelSmartSerialNumber");
        sizePolicy1.setHeightForWidth(m_LabelSmartSerialNumber->sizePolicy().hasHeightForWidth());
        m_LabelSmartSerialNumber->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(m_LabelSmartSerialNumber, 4, 1, 1, 2);

        m_LabelTextSmartFirmware = new QLabel(SmartDialogWidgetBase);
        m_LabelTextSmartFirmware->setObjectName("m_LabelTextSmartFirmware");
        sizePolicy.setHeightForWidth(m_LabelTextSmartFirmware->sizePolicy().hasHeightForWidth());
        m_LabelTextSmartFirmware->setSizePolicy(sizePolicy);
        m_LabelTextSmartFirmware->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(m_LabelTextSmartFirmware, 5, 0, 1, 1);

        m_LabelSmartFirmware = new QLabel(SmartDialogWidgetBase);
        m_LabelSmartFirmware->setObjectName("m_LabelSmartFirmware");
        sizePolicy1.setHeightForWidth(m_LabelSmartFirmware->sizePolicy().hasHeightForWidth());
        m_LabelSmartFirmware->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(m_LabelSmartFirmware, 5, 1, 1, 2);

        m_LabelTextSmartTemperature = new QLabel(SmartDialogWidgetBase);
        m_LabelTextSmartTemperature->setObjectName("m_LabelTextSmartTemperature");
        sizePolicy.setHeightForWidth(m_LabelTextSmartTemperature->sizePolicy().hasHeightForWidth());
        m_LabelTextSmartTemperature->setSizePolicy(sizePolicy);
        m_LabelTextSmartTemperature->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(m_LabelTextSmartTemperature, 3, 3, 1, 1);

        m_LabelSmartTemperature = new QLabel(SmartDialogWidgetBase);
        m_LabelSmartTemperature->setObjectName("m_LabelSmartTemperature");
        sizePolicy1.setHeightForWidth(m_LabelSmartTemperature->sizePolicy().hasHeightForWidth());
        m_LabelSmartTemperature->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(m_LabelSmartTemperature, 3, 4, 1, 2);

        m_LabelTextSmartBadSectors = new QLabel(SmartDialogWidgetBase);
        m_LabelTextSmartBadSectors->setObjectName("m_LabelTextSmartBadSectors");
        sizePolicy.setHeightForWidth(m_LabelTextSmartBadSectors->sizePolicy().hasHeightForWidth());
        m_LabelTextSmartBadSectors->setSizePolicy(sizePolicy);
        m_LabelTextSmartBadSectors->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(m_LabelTextSmartBadSectors, 4, 3, 1, 1);

        m_LabelSmartBadSectors = new QLabel(SmartDialogWidgetBase);
        m_LabelSmartBadSectors->setObjectName("m_LabelSmartBadSectors");
        sizePolicy1.setHeightForWidth(m_LabelSmartBadSectors->sizePolicy().hasHeightForWidth());
        m_LabelSmartBadSectors->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(m_LabelSmartBadSectors, 4, 4, 1, 2);

        m_LabelTextSmartPoweredOn = new QLabel(SmartDialogWidgetBase);
        m_LabelTextSmartPoweredOn->setObjectName("m_LabelTextSmartPoweredOn");
        sizePolicy.setHeightForWidth(m_LabelTextSmartPoweredOn->sizePolicy().hasHeightForWidth());
        m_LabelTextSmartPoweredOn->setSizePolicy(sizePolicy);
        m_LabelTextSmartPoweredOn->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(m_LabelTextSmartPoweredOn, 5, 3, 1, 1);

        m_LabelSmartPoweredOn = new QLabel(SmartDialogWidgetBase);
        m_LabelSmartPoweredOn->setObjectName("m_LabelSmartPoweredOn");
        sizePolicy1.setHeightForWidth(m_LabelSmartPoweredOn->sizePolicy().hasHeightForWidth());
        m_LabelSmartPoweredOn->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(m_LabelSmartPoweredOn, 5, 4, 1, 2);

        m_LabelTextSmartPowerCycles = new QLabel(SmartDialogWidgetBase);
        m_LabelTextSmartPowerCycles->setObjectName("m_LabelTextSmartPowerCycles");
        sizePolicy.setHeightForWidth(m_LabelTextSmartPowerCycles->sizePolicy().hasHeightForWidth());
        m_LabelTextSmartPowerCycles->setSizePolicy(sizePolicy);
        m_LabelTextSmartPowerCycles->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(m_LabelTextSmartPowerCycles, 1, 0, 1, 1);

        m_LabelSmartPowerCycles = new QLabel(SmartDialogWidgetBase);
        m_LabelSmartPowerCycles->setObjectName("m_LabelSmartPowerCycles");
        sizePolicy1.setHeightForWidth(m_LabelSmartPowerCycles->sizePolicy().hasHeightForWidth());
        m_LabelSmartPowerCycles->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(m_LabelSmartPowerCycles, 1, 1, 1, 2);

        verticalSpacer_3 = new QSpacerItem(641, 17, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_3, 15, 0, 1, 3);

        m_TreeSmartAttributes = new QTreeWidget(SmartDialogWidgetBase);
        m_TreeSmartAttributes->setObjectName("m_TreeSmartAttributes");
        m_TreeSmartAttributes->setAlternatingRowColors(true);
        m_TreeSmartAttributes->setRootIsDecorated(false);
        m_TreeSmartAttributes->setUniformRowHeights(true);
        m_TreeSmartAttributes->setAllColumnsShowFocus(true);

        gridLayout->addWidget(m_TreeSmartAttributes, 16, 0, 1, 6);

        verticalSpacer_2 = new QSpacerItem(638, 17, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_2, 17, 0, 1, 3);

        line = new QFrame(SmartDialogWidgetBase);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line, 2, 0, 1, 6);

        line_2 = new QFrame(SmartDialogWidgetBase);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line_2, 10, 0, 1, 6);

        m_LabelTextSmartOverallAssessment = new QLabel(SmartDialogWidgetBase);
        m_LabelTextSmartOverallAssessment->setObjectName("m_LabelTextSmartOverallAssessment");
        sizePolicy.setHeightForWidth(m_LabelTextSmartOverallAssessment->sizePolicy().hasHeightForWidth());
        m_LabelTextSmartOverallAssessment->setSizePolicy(sizePolicy);
        m_LabelTextSmartOverallAssessment->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(m_LabelTextSmartOverallAssessment, 0, 3, 1, 1);

        m_LabelSmartOverallAssessment = new QLabel(SmartDialogWidgetBase);
        m_LabelSmartOverallAssessment->setObjectName("m_LabelSmartOverallAssessment");
        sizePolicy1.setHeightForWidth(m_LabelSmartOverallAssessment->sizePolicy().hasHeightForWidth());
        m_LabelSmartOverallAssessment->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(m_LabelSmartOverallAssessment, 0, 4, 1, 2);

        m_LabelTextSmartSelfTests = new QLabel(SmartDialogWidgetBase);
        m_LabelTextSmartSelfTests->setObjectName("m_LabelTextSmartSelfTests");
        sizePolicy.setHeightForWidth(m_LabelTextSmartSelfTests->sizePolicy().hasHeightForWidth());
        m_LabelTextSmartSelfTests->setSizePolicy(sizePolicy);
        m_LabelTextSmartSelfTests->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(m_LabelTextSmartSelfTests, 1, 3, 1, 1);

        m_LabelSmartSelfTests = new QLabel(SmartDialogWidgetBase);
        m_LabelSmartSelfTests->setObjectName("m_LabelSmartSelfTests");
        sizePolicy1.setHeightForWidth(m_LabelSmartSelfTests->sizePolicy().hasHeightForWidth());
        m_LabelSmartSelfTests->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(m_LabelSmartSelfTests, 1, 4, 1, 2);


        retranslateUi(SmartDialogWidgetBase);

        QMetaObject::connectSlotsByName(SmartDialogWidgetBase);
    } // setupUi

    void retranslateUi(QWidget *SmartDialogWidgetBase)
    {
        m_LabelTextSmartStatus->setText(tr2i18n("SMART status:", nullptr));
        m_LabelSmartStatusIcon->setText(QString());
        m_LabelSmartStatusText->setText(QString());
        m_LabelTextSmartModelName->setText(tr2i18n("Model:", nullptr));
        m_LabelSmartModelName->setText(QString());
        m_LabelTextSmartSerialNumber->setText(tr2i18n("Serial number:", nullptr));
        m_LabelSmartSerialNumber->setText(QString());
        m_LabelTextSmartFirmware->setText(tr2i18n("Firmware revision:", nullptr));
        m_LabelSmartFirmware->setText(QString());
        m_LabelTextSmartTemperature->setText(tr2i18n("Temperature:", nullptr));
        m_LabelSmartTemperature->setText(QString());
        m_LabelTextSmartBadSectors->setText(tr2i18n("Bad sectors:", nullptr));
        m_LabelSmartBadSectors->setText(QString());
        m_LabelTextSmartPoweredOn->setText(tr2i18n("Powered on for:", nullptr));
        m_LabelSmartPoweredOn->setText(QString());
        m_LabelTextSmartPowerCycles->setText(tr2i18n("Power cycles:", nullptr));
        m_LabelSmartPowerCycles->setText(QString());
        QTreeWidgetItem *___qtreewidgetitem = m_TreeSmartAttributes->headerItem();
        ___qtreewidgetitem->setText(9, tr2i18n("Value", nullptr));
        ___qtreewidgetitem->setText(8, tr2i18n("Assessment", nullptr));
        ___qtreewidgetitem->setText(7, tr2i18n("Raw", nullptr));
        ___qtreewidgetitem->setText(6, tr2i18n("Threshold", nullptr));
        ___qtreewidgetitem->setText(5, tr2i18n("Current", nullptr));
        ___qtreewidgetitem->setText(4, tr2i18n("Worst", nullptr));
        ___qtreewidgetitem->setText(3, tr2i18n("Update Type", nullptr));
        ___qtreewidgetitem->setText(2, tr2i18n("Failure Type", nullptr));
        ___qtreewidgetitem->setText(1, tr2i18n("Attribute", nullptr));
        ___qtreewidgetitem->setText(0, tr2i18n("Id", nullptr));
        m_LabelTextSmartOverallAssessment->setText(tr2i18n("Overall assessment:", nullptr));
        m_LabelSmartOverallAssessment->setText(QString());
        m_LabelTextSmartSelfTests->setText(tr2i18n("Self tests:", nullptr));
        m_LabelSmartSelfTests->setText(QString());
        (void)SmartDialogWidgetBase;
    } // retranslateUi

};

namespace Ui {
    class SmartDialogWidgetBase: public Ui_SmartDialogWidgetBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SMARTDIALOGWIDGETBASE_H

