/********************************************************************************
** Form generated from reading UI file 'configurepageadvanced.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGUREPAGEADVANCED_H
#define UI_CONFIGUREPAGEADVANCED_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ConfigurePageAdvanced
{
public:
    QFormLayout *verticalLayout;
    QLabel *label_4;
    QComboBox *m_ComboBackend;
    QLabel *label;
    QComboBox *kcfg_preferredUnit;

    void setupUi(QWidget *ConfigurePageAdvanced)
    {
        if (ConfigurePageAdvanced->objectName().isEmpty())
            ConfigurePageAdvanced->setObjectName("ConfigurePageAdvanced");
        ConfigurePageAdvanced->resize(449, 420);
        verticalLayout = new QFormLayout(ConfigurePageAdvanced);
        verticalLayout->setObjectName("verticalLayout");
        label_4 = new QLabel(ConfigurePageAdvanced);
        label_4->setObjectName("label_4");

        verticalLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_4);

        m_ComboBackend = new QComboBox(ConfigurePageAdvanced);
        m_ComboBackend->setObjectName("m_ComboBackend");

        verticalLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, m_ComboBackend);

        label = new QLabel(ConfigurePageAdvanced);
        label->setObjectName("label");

        verticalLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label);

        kcfg_preferredUnit = new QComboBox(ConfigurePageAdvanced);
        kcfg_preferredUnit->addItem(QString());
        kcfg_preferredUnit->addItem(QString());
        kcfg_preferredUnit->addItem(QString());
        kcfg_preferredUnit->addItem(QString());
        kcfg_preferredUnit->addItem(QString());
        kcfg_preferredUnit->addItem(QString());
        kcfg_preferredUnit->addItem(QString());
        kcfg_preferredUnit->setObjectName("kcfg_preferredUnit");

        verticalLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_preferredUnit);

#if QT_CONFIG(shortcut)
        label_4->setBuddy(m_ComboBackend);
        label->setBuddy(kcfg_preferredUnit);
#endif // QT_CONFIG(shortcut)

        retranslateUi(ConfigurePageAdvanced);

        QMetaObject::connectSlotsByName(ConfigurePageAdvanced);
    } // setupUi

    void retranslateUi(QWidget *ConfigurePageAdvanced)
    {
        label_4->setText(tr2i18n("Active backend:", nullptr));
        label->setText(tr2i18n("Preferred unit:", nullptr));
        kcfg_preferredUnit->setItemText(0, tr2i18n("Byte", nullptr));
        kcfg_preferredUnit->setItemText(1, tr2i18n("KiB", nullptr));
        kcfg_preferredUnit->setItemText(2, tr2i18n("MiB", nullptr));
        kcfg_preferredUnit->setItemText(3, tr2i18n("GiB", nullptr));
        kcfg_preferredUnit->setItemText(4, tr2i18n("TiB", nullptr));
        kcfg_preferredUnit->setItemText(5, tr2i18n("PiB", nullptr));
        kcfg_preferredUnit->setItemText(6, tr2i18n("EiB", nullptr));

        (void)ConfigurePageAdvanced;
    } // retranslateUi

};

namespace Ui {
    class ConfigurePageAdvanced: public Ui_ConfigurePageAdvanced {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONFIGUREPAGEADVANCED_H

