/********************************************************************************
** Form generated from reading UI file 'configurepagefilesystemcolors.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGUREPAGEFILESYSTEMCOLORS_H
#define UI_CONFIGUREPAGEFILESYSTEMCOLORS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"

QT_BEGIN_NAMESPACE

class Ui_ConfigurePageFileSystemColors
{
public:
    QGridLayout *gridLayout;
    KColorButton *kcfg_fileSystemColorCodeReiserFS;
    QLabel *textLabel_7;
    KColorButton *kcfg_fileSystemColorCodeNilfs2;
    QSpacerItem *horizontalSpacer_03l;
    QLabel *textLabel_15;
    QLabel *textLabel_31;
    KColorButton *kcfg_fileSystemColorCodeHfs;
    KColorButton *kcfg_fileSystemColorCodeFat16;
    QLabel *textLabel_24;
    KColorButton *kcfg_fileSystemColorCodeExt3;
    QLabel *textLabel_22;
    KColorButton *kcfg_fileSystemColorCodeExt4;
    KColorButton *kcfg_fileSystemColorCodeUnformatted;
    QLabel *textLabel_27;
    QSpacerItem *horizontalSpacer_07l;
    QSpacerItem *horizontalSpacer_02r;
    QSpacerItem *horizontalSpacer_04r;
    QLabel *textLabel_6;
    QLabel *textLabel_13;
    QLabel *textLabel_33;
    KColorButton *kcfg_fileSystemColorCodeUdf;
    QLabel *textLabel_17;
    KColorButton *kcfg_fileSystemColorCodeJfs;
    KColorButton *kcfg_fileSystemColorCodeExt2;
    QLabel *textLabel_30;
    QLabel *textLabel_25;
    KColorButton *kcfg_fileSystemColorCodeHfsPlus;
    KColorButton *kcfg_fileSystemColorCodeFat32;
    KColorButton *kcfg_fileSystemColorCodeApfs;
    QSpacerItem *horizontalSpacer_05r;
    QSpacerItem *horizontalSpacer_08l;
    QLabel *textLabel_3;
    KColorButton *kcfg_fileSystemColorCodeFat12;
    QLabel *textLabel_10;
    KColorButton *kcfg_fileSystemColorCodeNtfs;
    QSpacerItem *horizontalSpacer_02l;
    QSpacerItem *horizontalSpacer_08r;
    QSpacerItem *horizontalSpacer_09l;
    KColorButton *kcfg_fileSystemColorCodeF2fs;
    QLabel *textLabel_11;
    QLabel *textLabel_2;
    QSpacerItem *horizontalSpacer_06r;
    QLabel *textLabel_8;
    KColorButton *kcfg_fileSystemColorCodeReiser4;
    KColorButton *kcfg_fileSystemColorCodeExtended;
    QSpacerItem *horizontalSpacer_09r;
    QLabel *textLabel_21;
    KColorButton *kcfg_fileSystemColorCodeExfat;
    QSpacerItem *horizontalSpacer_01l;
    QSpacerItem *horizontalSpacer_05l;
    QLabel *textLabel;
    KColorButton *kcfg_fileSystemColorCodeIso9660;
    KColorButton *kcfg_fileSystemColorCodeUfs;
    QLabel *textLabel_29;
    KColorButton *kcfg_fileSystemColorCodeUnknown;
    KColorButton *kcfg_fileSystemColorCodeBitLocker;
    QLabel *textLabel_28;
    QSpacerItem *horizontalSpacer_06l;
    QLabel *textLabel_26;
    KColorButton *kcfg_fileSystemColorCodeLinuxSwap;
    QLabel *textLabel_9;
    QSpacerItem *horizontalSpacer_04l;
    QLabel *textLabel_20;
    KColorButton *kcfg_fileSystemColorCodeBtrfs;
    QSpacerItem *horizontalSpacer_07r;
    QLabel *textLabel_4;
    QSpacerItem *horizontalSpacer_01r;
    KColorButton *kcfg_fileSystemColorCodeOcfs2;
    KColorButton *kcfg_fileSystemColorCodeZfs;
    KColorButton *kcfg_fileSystemColorCodeLuks2;
    KColorButton *kcfg_fileSystemColorCodeLuks;
    QSpacerItem *horizontalSpacer_10r;
    QLabel *textLabel_32;
    QLabel *textLabel_12;
    KColorButton *kcfg_fileSystemColorCodeLvm2_PV;
    QSpacerItem *horizontalSpacer_10l;
    KColorButton *kcfg_fileSystemColorCodeHpfs;
    QLabel *textLabel_35;
    QLabel *textLabel_5;
    KColorButton *kcfg_fileSystemColorCodeXfs;
    QSpacerItem *horizontalSpacer_03r;
    QLabel *textLabel_18;
    QLabel *textLabel_34;
    QSpacerItem *horizontalSpacer_unknown;
    KColorButton *kcfg_fileSystemColorCodeLinuxRaidMember;
    QLabel *textLabel_14;
    QSpacerItem *horizontalSpacer_unformatted;
    QLabel *textLabel_16;
    QLabel *textLabel_36;
    KColorButton *kcfg_fileSystemColorCodeMinix;
    QSpacerItem *horizontalSpacer11l;
    QLabel *textLabel_37;
    KColorButton *kcfg_fileSystemColorCodeBcachefs;
    QSpacerItem *horizontalSpacer11m;
    QFrame *line;

    void setupUi(QWidget *ConfigurePageFileSystemColors)
    {
        if (ConfigurePageFileSystemColors->objectName().isEmpty())
            ConfigurePageFileSystemColors->setObjectName("ConfigurePageFileSystemColors");
        ConfigurePageFileSystemColors->resize(484, 528);
        gridLayout = new QGridLayout(ConfigurePageFileSystemColors);
        gridLayout->setObjectName("gridLayout");
        kcfg_fileSystemColorCodeReiserFS = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeReiserFS->setObjectName("kcfg_fileSystemColorCodeReiserFS");

        gridLayout->addWidget(kcfg_fileSystemColorCodeReiserFS, 3, 7, 1, 1);

        textLabel_7 = new QLabel(ConfigurePageFileSystemColors);
        textLabel_7->setObjectName("textLabel_7");
        textLabel_7->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel_7->setWordWrap(false);

        gridLayout->addWidget(textLabel_7, 3, 6, 1, 1);

        kcfg_fileSystemColorCodeNilfs2 = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeNilfs2->setObjectName("kcfg_fileSystemColorCodeNilfs2");

        gridLayout->addWidget(kcfg_fileSystemColorCodeNilfs2, 7, 1, 1, 1);

        horizontalSpacer_03l = new QSpacerItem(43, 17, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_03l, 2, 2, 1, 1);

        textLabel_15 = new QLabel(ConfigurePageFileSystemColors);
        textLabel_15->setObjectName("textLabel_15");
        textLabel_15->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel_15->setWordWrap(false);

        gridLayout->addWidget(textLabel_15, 5, 3, 1, 1);

        textLabel_31 = new QLabel(ConfigurePageFileSystemColors);
        textLabel_31->setObjectName("textLabel_31");
        textLabel_31->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel_31->setWordWrap(false);

        gridLayout->addWidget(textLabel_31, 8, 3, 1, 1);

        kcfg_fileSystemColorCodeHfs = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeHfs->setObjectName("kcfg_fileSystemColorCodeHfs");

        gridLayout->addWidget(kcfg_fileSystemColorCodeHfs, 4, 7, 1, 1);

        kcfg_fileSystemColorCodeFat16 = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeFat16->setObjectName("kcfg_fileSystemColorCodeFat16");

        gridLayout->addWidget(kcfg_fileSystemColorCodeFat16, 2, 7, 1, 1);

        textLabel_24 = new QLabel(ConfigurePageFileSystemColors);
        textLabel_24->setObjectName("textLabel_24");
        textLabel_24->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel_24->setWordWrap(false);

        gridLayout->addWidget(textLabel_24, 6, 0, 1, 1);

        kcfg_fileSystemColorCodeExt3 = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeExt3->setObjectName("kcfg_fileSystemColorCodeExt3");

        gridLayout->addWidget(kcfg_fileSystemColorCodeExt3, 0, 4, 1, 1);

        textLabel_22 = new QLabel(ConfigurePageFileSystemColors);
        textLabel_22->setObjectName("textLabel_22");
        textLabel_22->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel_22->setWordWrap(false);

        gridLayout->addWidget(textLabel_22, 5, 6, 1, 1);

        kcfg_fileSystemColorCodeExt4 = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeExt4->setObjectName("kcfg_fileSystemColorCodeExt4");

        gridLayout->addWidget(kcfg_fileSystemColorCodeExt4, 0, 7, 1, 1);

        kcfg_fileSystemColorCodeUnformatted = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeUnformatted->setObjectName("kcfg_fileSystemColorCodeUnformatted");

        gridLayout->addWidget(kcfg_fileSystemColorCodeUnformatted, 13, 4, 1, 1);

        textLabel_27 = new QLabel(ConfigurePageFileSystemColors);
        textLabel_27->setObjectName("textLabel_27");
        textLabel_27->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(textLabel_27, 7, 0, 1, 1);

        horizontalSpacer_07l = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_07l, 6, 2, 1, 1);

        horizontalSpacer_02r = new QSpacerItem(28, 17, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_02r, 1, 5, 1, 1);

        horizontalSpacer_04r = new QSpacerItem(43, 17, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_04r, 3, 5, 1, 1);

        textLabel_6 = new QLabel(ConfigurePageFileSystemColors);
        textLabel_6->setObjectName("textLabel_6");
        textLabel_6->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel_6->setWordWrap(false);

        gridLayout->addWidget(textLabel_6, 2, 6, 1, 1);

        textLabel_13 = new QLabel(ConfigurePageFileSystemColors);
        textLabel_13->setObjectName("textLabel_13");
        textLabel_13->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel_13->setWordWrap(false);

        gridLayout->addWidget(textLabel_13, 13, 0, 1, 1);

        textLabel_33 = new QLabel(ConfigurePageFileSystemColors);
        textLabel_33->setObjectName("textLabel_33");
        textLabel_33->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel_33->setWordWrap(false);

        gridLayout->addWidget(textLabel_33, 9, 0, 1, 1);

        kcfg_fileSystemColorCodeUdf = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeUdf->setObjectName("kcfg_fileSystemColorCodeUdf");

        gridLayout->addWidget(kcfg_fileSystemColorCodeUdf, 8, 1, 1, 1);

        textLabel_17 = new QLabel(ConfigurePageFileSystemColors);
        textLabel_17->setObjectName("textLabel_17");
        textLabel_17->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel_17->setWordWrap(false);

        gridLayout->addWidget(textLabel_17, 13, 3, 1, 1);

        kcfg_fileSystemColorCodeJfs = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeJfs->setObjectName("kcfg_fileSystemColorCodeJfs");

        gridLayout->addWidget(kcfg_fileSystemColorCodeJfs, 4, 4, 1, 1);

        kcfg_fileSystemColorCodeExt2 = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeExt2->setObjectName("kcfg_fileSystemColorCodeExt2");

        gridLayout->addWidget(kcfg_fileSystemColorCodeExt2, 0, 1, 1, 1);

        textLabel_30 = new QLabel(ConfigurePageFileSystemColors);
        textLabel_30->setObjectName("textLabel_30");
        textLabel_30->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel_30->setWordWrap(false);

        gridLayout->addWidget(textLabel_30, 8, 0, 1, 1);

        textLabel_25 = new QLabel(ConfigurePageFileSystemColors);
        textLabel_25->setObjectName("textLabel_25");
        textLabel_25->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel_25->setWordWrap(false);

        gridLayout->addWidget(textLabel_25, 6, 3, 1, 1);

        kcfg_fileSystemColorCodeHfsPlus = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeHfsPlus->setObjectName("kcfg_fileSystemColorCodeHfsPlus");

        gridLayout->addWidget(kcfg_fileSystemColorCodeHfsPlus, 5, 1, 1, 1);

        kcfg_fileSystemColorCodeFat32 = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeFat32->setObjectName("kcfg_fileSystemColorCodeFat32");

        gridLayout->addWidget(kcfg_fileSystemColorCodeFat32, 3, 1, 1, 1);

        kcfg_fileSystemColorCodeApfs = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeApfs->setObjectName("kcfg_fileSystemColorCodeApfs");

        gridLayout->addWidget(kcfg_fileSystemColorCodeApfs, 9, 7, 1, 1);

        horizontalSpacer_05r = new QSpacerItem(28, 17, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_05r, 4, 5, 1, 1);

        horizontalSpacer_08l = new QSpacerItem(43, 17, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_08l, 7, 2, 1, 1);

        textLabel_3 = new QLabel(ConfigurePageFileSystemColors);
        textLabel_3->setObjectName("textLabel_3");
        textLabel_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel_3->setWordWrap(false);

        gridLayout->addWidget(textLabel_3, 0, 6, 1, 1);

        kcfg_fileSystemColorCodeFat12 = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeFat12->setObjectName("kcfg_fileSystemColorCodeFat12");

        gridLayout->addWidget(kcfg_fileSystemColorCodeFat12, 2, 4, 1, 1);

        textLabel_10 = new QLabel(ConfigurePageFileSystemColors);
        textLabel_10->setObjectName("textLabel_10");
        textLabel_10->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel_10->setWordWrap(false);

        gridLayout->addWidget(textLabel_10, 3, 3, 1, 1);

        kcfg_fileSystemColorCodeNtfs = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeNtfs->setObjectName("kcfg_fileSystemColorCodeNtfs");

        gridLayout->addWidget(kcfg_fileSystemColorCodeNtfs, 1, 4, 1, 1);

        horizontalSpacer_02l = new QSpacerItem(37, 18, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_02l, 1, 2, 1, 1);

        horizontalSpacer_08r = new QSpacerItem(43, 17, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_08r, 7, 5, 1, 1);

        horizontalSpacer_09l = new QSpacerItem(43, 17, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_09l, 8, 2, 1, 1);

        kcfg_fileSystemColorCodeF2fs = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeF2fs->setObjectName("kcfg_fileSystemColorCodeF2fs");

        gridLayout->addWidget(kcfg_fileSystemColorCodeF2fs, 7, 7, 1, 1);

        textLabel_11 = new QLabel(ConfigurePageFileSystemColors);
        textLabel_11->setObjectName("textLabel_11");
        textLabel_11->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel_11->setWordWrap(false);

        gridLayout->addWidget(textLabel_11, 4, 3, 1, 1);

        textLabel_2 = new QLabel(ConfigurePageFileSystemColors);
        textLabel_2->setObjectName("textLabel_2");
        textLabel_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel_2->setWordWrap(false);

        gridLayout->addWidget(textLabel_2, 0, 3, 1, 1);

        horizontalSpacer_06r = new QSpacerItem(28, 17, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_06r, 5, 5, 1, 1);

        textLabel_8 = new QLabel(ConfigurePageFileSystemColors);
        textLabel_8->setObjectName("textLabel_8");
        textLabel_8->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel_8->setWordWrap(false);

        gridLayout->addWidget(textLabel_8, 4, 0, 1, 1);

        kcfg_fileSystemColorCodeReiser4 = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeReiser4->setObjectName("kcfg_fileSystemColorCodeReiser4");

        gridLayout->addWidget(kcfg_fileSystemColorCodeReiser4, 4, 1, 1, 1);

        kcfg_fileSystemColorCodeExtended = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeExtended->setObjectName("kcfg_fileSystemColorCodeExtended");

        gridLayout->addWidget(kcfg_fileSystemColorCodeExtended, 13, 1, 1, 1);

        horizontalSpacer_09r = new QSpacerItem(43, 17, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_09r, 8, 5, 1, 1);

        textLabel_21 = new QLabel(ConfigurePageFileSystemColors);
        textLabel_21->setObjectName("textLabel_21");
        textLabel_21->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel_21->setWordWrap(false);

        gridLayout->addWidget(textLabel_21, 1, 0, 1, 1);

        kcfg_fileSystemColorCodeExfat = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeExfat->setObjectName("kcfg_fileSystemColorCodeExfat");

        gridLayout->addWidget(kcfg_fileSystemColorCodeExfat, 6, 7, 1, 1);

        horizontalSpacer_01l = new QSpacerItem(28, 17, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_01l, 0, 2, 1, 1);

        horizontalSpacer_05l = new QSpacerItem(43, 17, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_05l, 4, 2, 1, 1);

        textLabel = new QLabel(ConfigurePageFileSystemColors);
        textLabel->setObjectName("textLabel");
        textLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel->setWordWrap(false);

        gridLayout->addWidget(textLabel, 0, 0, 1, 1);

        kcfg_fileSystemColorCodeIso9660 = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeIso9660->setObjectName("kcfg_fileSystemColorCodeIso9660");

        gridLayout->addWidget(kcfg_fileSystemColorCodeIso9660, 8, 4, 1, 1);

        kcfg_fileSystemColorCodeUfs = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeUfs->setObjectName("kcfg_fileSystemColorCodeUfs");

        gridLayout->addWidget(kcfg_fileSystemColorCodeUfs, 5, 4, 1, 1);

        textLabel_29 = new QLabel(ConfigurePageFileSystemColors);
        textLabel_29->setObjectName("textLabel_29");
        textLabel_29->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel_29->setWordWrap(false);

        gridLayout->addWidget(textLabel_29, 7, 6, 1, 1);

        kcfg_fileSystemColorCodeUnknown = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeUnknown->setObjectName("kcfg_fileSystemColorCodeUnknown");

        gridLayout->addWidget(kcfg_fileSystemColorCodeUnknown, 13, 7, 1, 1);

        kcfg_fileSystemColorCodeBitLocker = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeBitLocker->setObjectName("kcfg_fileSystemColorCodeBitLocker");

        gridLayout->addWidget(kcfg_fileSystemColorCodeBitLocker, 9, 4, 1, 1);

        textLabel_28 = new QLabel(ConfigurePageFileSystemColors);
        textLabel_28->setObjectName("textLabel_28");
        textLabel_28->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel_28->setWordWrap(false);

        gridLayout->addWidget(textLabel_28, 7, 3, 1, 1);

        horizontalSpacer_06l = new QSpacerItem(43, 17, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_06l, 5, 2, 1, 1);

        textLabel_26 = new QLabel(ConfigurePageFileSystemColors);
        textLabel_26->setObjectName("textLabel_26");
        textLabel_26->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(textLabel_26, 6, 6, 1, 1);

        kcfg_fileSystemColorCodeLinuxSwap = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeLinuxSwap->setObjectName("kcfg_fileSystemColorCodeLinuxSwap");

        gridLayout->addWidget(kcfg_fileSystemColorCodeLinuxSwap, 2, 1, 1, 1);

        textLabel_9 = new QLabel(ConfigurePageFileSystemColors);
        textLabel_9->setObjectName("textLabel_9");
        textLabel_9->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel_9->setWordWrap(false);

        gridLayout->addWidget(textLabel_9, 1, 3, 1, 1);

        horizontalSpacer_04l = new QSpacerItem(28, 17, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_04l, 3, 2, 1, 1);

        textLabel_20 = new QLabel(ConfigurePageFileSystemColors);
        textLabel_20->setObjectName("textLabel_20");
        textLabel_20->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel_20->setWordWrap(false);

        gridLayout->addWidget(textLabel_20, 8, 6, 1, 1);

        kcfg_fileSystemColorCodeBtrfs = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeBtrfs->setObjectName("kcfg_fileSystemColorCodeBtrfs");

        gridLayout->addWidget(kcfg_fileSystemColorCodeBtrfs, 1, 1, 1, 1);

        horizontalSpacer_07r = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_07r, 6, 5, 1, 1);

        textLabel_4 = new QLabel(ConfigurePageFileSystemColors);
        textLabel_4->setObjectName("textLabel_4");
        textLabel_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel_4->setWordWrap(false);

        gridLayout->addWidget(textLabel_4, 2, 0, 1, 1);

        horizontalSpacer_01r = new QSpacerItem(43, 17, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_01r, 0, 5, 1, 1);

        kcfg_fileSystemColorCodeOcfs2 = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeOcfs2->setObjectName("kcfg_fileSystemColorCodeOcfs2");

        gridLayout->addWidget(kcfg_fileSystemColorCodeOcfs2, 6, 1, 1, 1);

        kcfg_fileSystemColorCodeZfs = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeZfs->setObjectName("kcfg_fileSystemColorCodeZfs");

        gridLayout->addWidget(kcfg_fileSystemColorCodeZfs, 6, 4, 1, 1);

        kcfg_fileSystemColorCodeLuks2 = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeLuks2->setObjectName("kcfg_fileSystemColorCodeLuks2");

        gridLayout->addWidget(kcfg_fileSystemColorCodeLuks2, 9, 1, 1, 1);

        kcfg_fileSystemColorCodeLuks = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeLuks->setObjectName("kcfg_fileSystemColorCodeLuks");

        gridLayout->addWidget(kcfg_fileSystemColorCodeLuks, 8, 7, 1, 1);

        horizontalSpacer_10r = new QSpacerItem(43, 17, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_10r, 9, 5, 1, 1);

        textLabel_32 = new QLabel(ConfigurePageFileSystemColors);
        textLabel_32->setObjectName("textLabel_32");
        textLabel_32->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel_32->setWordWrap(false);

        gridLayout->addWidget(textLabel_32, 2, 3, 1, 1);

        textLabel_12 = new QLabel(ConfigurePageFileSystemColors);
        textLabel_12->setObjectName("textLabel_12");
        textLabel_12->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel_12->setWordWrap(false);

        gridLayout->addWidget(textLabel_12, 4, 6, 1, 1);

        kcfg_fileSystemColorCodeLvm2_PV = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeLvm2_PV->setObjectName("kcfg_fileSystemColorCodeLvm2_PV");

        gridLayout->addWidget(kcfg_fileSystemColorCodeLvm2_PV, 7, 4, 1, 1);

        horizontalSpacer_10l = new QSpacerItem(43, 17, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_10l, 9, 2, 1, 1);

        kcfg_fileSystemColorCodeHpfs = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeHpfs->setObjectName("kcfg_fileSystemColorCodeHpfs");

        gridLayout->addWidget(kcfg_fileSystemColorCodeHpfs, 3, 4, 1, 1);

        textLabel_35 = new QLabel(ConfigurePageFileSystemColors);
        textLabel_35->setObjectName("textLabel_35");
        textLabel_35->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel_35->setWordWrap(false);

        gridLayout->addWidget(textLabel_35, 9, 6, 1, 1);

        textLabel_5 = new QLabel(ConfigurePageFileSystemColors);
        textLabel_5->setObjectName("textLabel_5");
        textLabel_5->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel_5->setWordWrap(false);

        gridLayout->addWidget(textLabel_5, 3, 0, 1, 1);

        kcfg_fileSystemColorCodeXfs = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeXfs->setObjectName("kcfg_fileSystemColorCodeXfs");

        gridLayout->addWidget(kcfg_fileSystemColorCodeXfs, 5, 7, 1, 1);

        horizontalSpacer_03r = new QSpacerItem(43, 17, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_03r, 2, 5, 1, 1);

        textLabel_18 = new QLabel(ConfigurePageFileSystemColors);
        textLabel_18->setObjectName("textLabel_18");
        textLabel_18->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel_18->setWordWrap(false);

        gridLayout->addWidget(textLabel_18, 1, 6, 1, 1);

        textLabel_34 = new QLabel(ConfigurePageFileSystemColors);
        textLabel_34->setObjectName("textLabel_34");
        textLabel_34->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel_34->setWordWrap(false);

        gridLayout->addWidget(textLabel_34, 9, 3, 1, 1);

        horizontalSpacer_unknown = new QSpacerItem(21, 21, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_unknown, 13, 5, 1, 1);

        kcfg_fileSystemColorCodeLinuxRaidMember = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeLinuxRaidMember->setObjectName("kcfg_fileSystemColorCodeLinuxRaidMember");

        gridLayout->addWidget(kcfg_fileSystemColorCodeLinuxRaidMember, 1, 7, 1, 1);

        textLabel_14 = new QLabel(ConfigurePageFileSystemColors);
        textLabel_14->setObjectName("textLabel_14");
        textLabel_14->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel_14->setWordWrap(false);

        gridLayout->addWidget(textLabel_14, 5, 0, 1, 1);

        horizontalSpacer_unformatted = new QSpacerItem(28, 17, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_unformatted, 13, 2, 1, 1);

        textLabel_16 = new QLabel(ConfigurePageFileSystemColors);
        textLabel_16->setObjectName("textLabel_16");
        textLabel_16->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel_16->setWordWrap(false);

        gridLayout->addWidget(textLabel_16, 13, 6, 1, 1);

        textLabel_36 = new QLabel(ConfigurePageFileSystemColors);
        textLabel_36->setObjectName("textLabel_36");
        textLabel_36->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(textLabel_36, 11, 0, 1, 1);

        kcfg_fileSystemColorCodeMinix = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeMinix->setObjectName("kcfg_fileSystemColorCodeMinix");

        gridLayout->addWidget(kcfg_fileSystemColorCodeMinix, 11, 1, 1, 1);

        horizontalSpacer11l = new QSpacerItem(43, 17, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer11l, 11, 2, 1, 1);

        textLabel_37 = new QLabel(ConfigurePageFileSystemColors);
        textLabel_37->setObjectName("textLabel_37");
        textLabel_37->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(textLabel_37, 11, 3, 1, 1);

        kcfg_fileSystemColorCodeBcachefs = new KColorButton(ConfigurePageFileSystemColors);
        kcfg_fileSystemColorCodeBcachefs->setObjectName("kcfg_fileSystemColorCodeBcachefs");

        gridLayout->addWidget(kcfg_fileSystemColorCodeBcachefs, 11, 4, 1, 1);

        horizontalSpacer11m = new QSpacerItem(43, 17, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer11m, 11, 5, 1, 1);

        line = new QFrame(ConfigurePageFileSystemColors);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line, 12, 0, 1, 8);


        retranslateUi(ConfigurePageFileSystemColors);

        QMetaObject::connectSlotsByName(ConfigurePageFileSystemColors);
    } // setupUi

    void retranslateUi(QWidget *ConfigurePageFileSystemColors)
    {
        textLabel_7->setText(tr2i18n("ReiserFS:", nullptr));
        textLabel_15->setText(tr2i18n("UFS:", nullptr));
        textLabel_31->setText(tr2i18n("ISO 9660:", nullptr));
        textLabel_24->setText(tr2i18n("OCFS2:", nullptr));
        textLabel_22->setText(tr2i18n("XFS:", nullptr));
        textLabel_27->setText(tr2i18n("NILFS2:", nullptr));
        textLabel_6->setText(tr2i18n("FAT16:", nullptr));
        textLabel_13->setText(tr2i18n("extended:", nullptr));
        textLabel_33->setText(tr2i18n("LUKS2:", nullptr));
        textLabel_17->setText(tr2i18n("unformatted:", nullptr));
        textLabel_30->setText(tr2i18n("UDF:", nullptr));
        textLabel_25->setText(tr2i18n("ZFS:", nullptr));
        textLabel_3->setText(tr2i18n("ext4:", nullptr));
        textLabel_10->setText(tr2i18n("HPFS:", nullptr));
        textLabel_11->setText(tr2i18n("JFS:", nullptr));
        textLabel_2->setText(tr2i18n("ext3:", nullptr));
        textLabel_8->setText(tr2i18n("Reiser4:", nullptr));
        textLabel_21->setText(tr2i18n("Btrfs:", nullptr));
        textLabel->setText(tr2i18n("ext2:", nullptr));
        textLabel_29->setText(tr2i18n("F2FS:", nullptr));
        textLabel_28->setText(tr2i18n("LVM2 PV:", nullptr));
        textLabel_26->setText(tr2i18n("exFAT:", nullptr));
        textLabel_9->setText(tr2i18n("NTFS:", nullptr));
        textLabel_20->setText(tr2i18n("LUKS:", nullptr));
        textLabel_4->setText(tr2i18n("Linux Swap:", nullptr));
        textLabel_32->setText(tr2i18n("FAT12:", nullptr));
        textLabel_12->setText(tr2i18n("HFS:", nullptr));
        textLabel_35->setText(tr2i18n("APFS:", nullptr));
        textLabel_5->setText(tr2i18n("FAT32:", nullptr));
        textLabel_18->setText(tr2i18n("Linux RAID:", nullptr));
        textLabel_34->setText(tr2i18n("BitLocker:", nullptr));
        textLabel_14->setText(tr2i18n("HFS+:", nullptr));
        textLabel_16->setText(tr2i18n("unknown:", nullptr));
        textLabel_36->setText(tr2i18n("Minix:", nullptr));
        textLabel_37->setText(tr2i18n("Bcachefs:", nullptr));
        (void)ConfigurePageFileSystemColors;
    } // retranslateUi

};

namespace Ui {
    class ConfigurePageFileSystemColors: public Ui_ConfigurePageFileSystemColors {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONFIGUREPAGEFILESYSTEMCOLORS_H

