/********************************************************************************
** Form generated from reading UI file 'treelogbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TREELOGBASE_H
#define UI_TREELOGBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_TreeLogBase
{
public:
    QVBoxLayout *verticalLayout;
    QTreeWidget *m_TreeLog;

    void setupUi(QWidget *TreeLogBase)
    {
        if (TreeLogBase->objectName().isEmpty())
            TreeLogBase->setObjectName("TreeLogBase");
        TreeLogBase->resize(565, 209);
        verticalLayout = new QVBoxLayout(TreeLogBase);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout->setObjectName("verticalLayout");
        m_TreeLog = new QTreeWidget(TreeLogBase);
        m_TreeLog->setObjectName("m_TreeLog");
        m_TreeLog->setContextMenuPolicy(Qt::CustomContextMenu);
        m_TreeLog->setAutoScroll(false);
        m_TreeLog->setSelectionMode(QAbstractItemView::NoSelection);
        m_TreeLog->setTextElideMode(Qt::ElideNone);
        m_TreeLog->setIndentation(0);
        m_TreeLog->setRootIsDecorated(false);
        m_TreeLog->setItemsExpandable(false);
        m_TreeLog->setWordWrap(true);
        m_TreeLog->setHeaderHidden(false);
        m_TreeLog->setExpandsOnDoubleClick(false);
        m_TreeLog->header()->setVisible(true);

        verticalLayout->addWidget(m_TreeLog);


        retranslateUi(TreeLogBase);

        QMetaObject::connectSlotsByName(TreeLogBase);
    } // setupUi

    void retranslateUi(QWidget *TreeLogBase)
    {
        QTreeWidgetItem *___qtreewidgetitem = m_TreeLog->headerItem();
        ___qtreewidgetitem->setText(2, tr2i18n("Message", "@title:column the text message of a log entry"));
        ___qtreewidgetitem->setText(1, tr2i18n("Time", "@title:column a time stamp of a log entry"));
        ___qtreewidgetitem->setText(0, tr2i18n("Sev.", "@title:column Severity of a log entry / log level. Text must be very short."));
#if QT_CONFIG(tooltip)
        ___qtreewidgetitem->setToolTip(0, tr2i18n("Severity", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)TreeLogBase;
    } // retranslateUi

};

namespace Ui {
    class TreeLogBase: public Ui_TreeLogBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TREELOGBASE_H

