/********************************************************************************
** Form generated from reading UI file 'mainwindowbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MAINWINDOWBASE_H
#define UI_MAINWINDOWBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDockWidget>
#include <QtWidgets/QMainWindow>
#include <klocalizedstring.h>
#include "gui/infopane.h"
#include "gui/listdevices.h"
#include "gui/listoperations.h"
#include "gui/partitionmanagerwidget.h"
#include "gui/treelog.h"
#include "kmessagewidget.h"

QT_BEGIN_NAMESPACE

class Ui_MainWindowBase
{
public:
    PartitionManagerWidget *m_PartitionManagerWidget;
    QDockWidget *m_DockDevices;
    ListDevices *m_ListDevices;
    QDockWidget *m_DockOperations;
    ListOperations *m_ListOperations;
    QDockWidget *m_DockInformation;
    InfoPane *m_InfoPane;
    QDockWidget *m_DockLog;
    TreeLog *m_TreeLog;
    QDockWidget *MessageWidgetDock;
    KMessageWidget *m_MessageWidget;

    void setupUi(QMainWindow *MainWindowBase)
    {
        if (MainWindowBase->objectName().isEmpty())
            MainWindowBase->setObjectName("MainWindowBase");
        MainWindowBase->resize(1007, 684);
        m_PartitionManagerWidget = new PartitionManagerWidget(MainWindowBase);
        m_PartitionManagerWidget->setObjectName("m_PartitionManagerWidget");
        MainWindowBase->setCentralWidget(m_PartitionManagerWidget);
        m_DockDevices = new QDockWidget(MainWindowBase);
        m_DockDevices->setObjectName("m_DockDevices");
        m_DockDevices->setAllowedAreas(Qt::LeftDockWidgetArea|Qt::RightDockWidgetArea);
        m_ListDevices = new ListDevices();
        m_ListDevices->setObjectName("m_ListDevices");
        m_DockDevices->setWidget(m_ListDevices);
        MainWindowBase->addDockWidget(Qt::DockWidgetArea::LeftDockWidgetArea, m_DockDevices);
        m_DockOperations = new QDockWidget(MainWindowBase);
        m_DockOperations->setObjectName("m_DockOperations");
        m_DockOperations->setAllowedAreas(Qt::BottomDockWidgetArea|Qt::LeftDockWidgetArea|Qt::RightDockWidgetArea);
        m_ListOperations = new ListOperations();
        m_ListOperations->setObjectName("m_ListOperations");
        m_DockOperations->setWidget(m_ListOperations);
        MainWindowBase->addDockWidget(Qt::DockWidgetArea::BottomDockWidgetArea, m_DockOperations);
        m_DockInformation = new QDockWidget(MainWindowBase);
        m_DockInformation->setObjectName("m_DockInformation");
        m_InfoPane = new InfoPane();
        m_InfoPane->setObjectName("m_InfoPane");
        m_DockInformation->setWidget(m_InfoPane);
        MainWindowBase->addDockWidget(Qt::DockWidgetArea::LeftDockWidgetArea, m_DockInformation);
        m_DockLog = new QDockWidget(MainWindowBase);
        m_DockLog->setObjectName("m_DockLog");
        m_DockLog->setAllowedAreas(Qt::BottomDockWidgetArea|Qt::TopDockWidgetArea);
        m_TreeLog = new TreeLog();
        m_TreeLog->setObjectName("m_TreeLog");
        m_DockLog->setWidget(m_TreeLog);
        MainWindowBase->addDockWidget(Qt::DockWidgetArea::BottomDockWidgetArea, m_DockLog);
        MessageWidgetDock = new QDockWidget(MainWindowBase);
        MessageWidgetDock->setObjectName("MessageWidgetDock");
        MessageWidgetDock->setMinimumSize(QSize(0, 0));
        MessageWidgetDock->setFeatures(QDockWidget::NoDockWidgetFeatures);
        m_MessageWidget = new KMessageWidget();
        m_MessageWidget->setObjectName("m_MessageWidget");
        m_MessageWidget->setMessageType(KMessageWidget::Warning);
        m_MessageWidget->setPosition(KMessageWidget::Header);
        MessageWidgetDock->setWidget(m_MessageWidget);
        MainWindowBase->addDockWidget(Qt::DockWidgetArea::TopDockWidgetArea, MessageWidgetDock);

        retranslateUi(MainWindowBase);

        QMetaObject::connectSlotsByName(MainWindowBase);
    } // setupUi

    void retranslateUi(QMainWindow *MainWindowBase)
    {
        MainWindowBase->setWindowTitle(tr2i18n("KDE Partition Manager", "@title:window"));
        m_DockDevices->setWindowTitle(tr2i18n("Devices", "@title:window"));
        m_DockOperations->setWindowTitle(tr2i18n("Pending Operations", "@title:window"));
        m_DockInformation->setWindowTitle(tr2i18n("Information", "@title:window"));
        m_DockLog->setWindowTitle(tr2i18n("Log Output", "@title:window"));
    } // retranslateUi

};

namespace Ui {
    class MainWindowBase: public Ui_MainWindowBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MAINWINDOWBASE_H

