/********************************************************************************
** Form generated from reading UI file 'createpartitiontablewidgetbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CREATEPARTITIONTABLEWIDGETBASE_H
#define UI_CREATEPARTITIONTABLEWIDGETBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_CreatePartitionTableWidgetBase
{
public:
    QVBoxLayout *verticalLayout_2;
    QLabel *label;
    QVBoxLayout *verticalLayout;
    QRadioButton *m_RadioGPT;
    QRadioButton *m_RadioMSDOS;
    QFrame *line;
    QHBoxLayout *horizontalLayout;
    QLabel *m_IconLabel;
    QLabel *label_3;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *CreatePartitionTableWidgetBase)
    {
        if (CreatePartitionTableWidgetBase->objectName().isEmpty())
            CreatePartitionTableWidgetBase->setObjectName("CreatePartitionTableWidgetBase");
        CreatePartitionTableWidgetBase->resize(325, 193);
        verticalLayout_2 = new QVBoxLayout(CreatePartitionTableWidgetBase);
        verticalLayout_2->setSpacing(10);
        verticalLayout_2->setObjectName("verticalLayout_2");
        label = new QLabel(CreatePartitionTableWidgetBase);
        label->setObjectName("label");

        verticalLayout_2->addWidget(label);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        m_RadioGPT = new QRadioButton(CreatePartitionTableWidgetBase);
        m_RadioGPT->setObjectName("m_RadioGPT");
        m_RadioGPT->setChecked(true);

        verticalLayout->addWidget(m_RadioGPT);

        m_RadioMSDOS = new QRadioButton(CreatePartitionTableWidgetBase);
        m_RadioMSDOS->setObjectName("m_RadioMSDOS");
        m_RadioMSDOS->setChecked(false);

        verticalLayout->addWidget(m_RadioMSDOS);


        verticalLayout_2->addLayout(verticalLayout);

        line = new QFrame(CreatePartitionTableWidgetBase);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_2->addWidget(line);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        m_IconLabel = new QLabel(CreatePartitionTableWidgetBase);
        m_IconLabel->setObjectName("m_IconLabel");
        m_IconLabel->setMinimumSize(QSize(32, 32));
        m_IconLabel->setAlignment(Qt::AlignCenter);
        m_IconLabel->setMargin(0);

        horizontalLayout->addWidget(m_IconLabel);

        label_3 = new QLabel(CreatePartitionTableWidgetBase);
        label_3->setObjectName("label_3");

        horizontalLayout->addWidget(label_3);


        verticalLayout_2->addLayout(horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        verticalLayout_2->addItem(verticalSpacer);


        retranslateUi(CreatePartitionTableWidgetBase);

        QMetaObject::connectSlotsByName(CreatePartitionTableWidgetBase);
    } // setupUi

    void retranslateUi(QWidget *CreatePartitionTableWidgetBase)
    {
        label->setText(tr2i18n("Choose the type of partition table you want to create:", nullptr));
        m_RadioGPT->setText(tr2i18n("GPT", nullptr));
        m_RadioMSDOS->setText(tr2i18n("MS-Dos", nullptr));
        m_IconLabel->setText(tr2i18n("(icon)", nullptr));
        label_3->setText(tr2i18n("<b>Warning:</b> This will destroy all data on the device!", nullptr));
        (void)CreatePartitionTableWidgetBase;
    } // retranslateUi

};

namespace Ui {
    class CreatePartitionTableWidgetBase: public Ui_CreatePartitionTableWidgetBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CREATEPARTITIONTABLEWIDGETBASE_H

