/********************************************************************************
** Form generated from reading UI file 'configurepagegeneral.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGUREPAGEGENERAL_H
#define UI_CONFIGUREPAGEGENERAL_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ConfigurePageGeneral
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_3;
    QCheckBox *kcfg_alignDefault;
    QLabel *label;
    QSpinBox *kcfg_sectorAlignment;
    QGroupBox *groupBox_3;
    QHBoxLayout *horizontalLayout;
    QLabel *label_2;
    QComboBox *kcfg_minLogLevel;
    QGroupBox *groupBox_4;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_3;
    QComboBox *m_ComboDefaultFileSystem;
    QGroupBox *groupBox_5;
    QHBoxLayout *horizontalLayout_4;
    QLabel *label_5;
    QRadioButton *radioButton;
    QRadioButton *radioButton_2;
    QButtonGroup *kcfg_shredSource;

    void setupUi(QWidget *ConfigurePageGeneral)
    {
        if (ConfigurePageGeneral->objectName().isEmpty())
            ConfigurePageGeneral->setObjectName("ConfigurePageGeneral");
        ConfigurePageGeneral->resize(427, 372);
        verticalLayout = new QVBoxLayout(ConfigurePageGeneral);
        verticalLayout->setObjectName("verticalLayout");
        groupBox_2 = new QGroupBox(ConfigurePageGeneral);
        groupBox_2->setObjectName("groupBox_2");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(1);
        sizePolicy.setHeightForWidth(groupBox_2->sizePolicy().hasHeightForWidth());
        groupBox_2->setSizePolicy(sizePolicy);
        gridLayout_3 = new QGridLayout(groupBox_2);
        gridLayout_3->setObjectName("gridLayout_3");
        kcfg_alignDefault = new QCheckBox(groupBox_2);
        kcfg_alignDefault->setObjectName("kcfg_alignDefault");
        kcfg_alignDefault->setChecked(true);

        gridLayout_3->addWidget(kcfg_alignDefault, 0, 0, 1, 2);

        label = new QLabel(groupBox_2);
        label->setObjectName("label");
        label->setEnabled(true);

        gridLayout_3->addWidget(label, 1, 0, 1, 1);

        kcfg_sectorAlignment = new QSpinBox(groupBox_2);
        kcfg_sectorAlignment->setObjectName("kcfg_sectorAlignment");
        kcfg_sectorAlignment->setEnabled(true);
        kcfg_sectorAlignment->setMinimum(1);
        kcfg_sectorAlignment->setMaximum(16777215);
        kcfg_sectorAlignment->setSingleStep(512);
        kcfg_sectorAlignment->setValue(2048);

        gridLayout_3->addWidget(kcfg_sectorAlignment, 1, 1, 1, 1);


        verticalLayout->addWidget(groupBox_2);

        groupBox_3 = new QGroupBox(ConfigurePageGeneral);
        groupBox_3->setObjectName("groupBox_3");
        sizePolicy.setHeightForWidth(groupBox_3->sizePolicy().hasHeightForWidth());
        groupBox_3->setSizePolicy(sizePolicy);
        horizontalLayout = new QHBoxLayout(groupBox_3);
        horizontalLayout->setObjectName("horizontalLayout");
        label_2 = new QLabel(groupBox_3);
        label_2->setObjectName("label_2");

        horizontalLayout->addWidget(label_2);

        kcfg_minLogLevel = new QComboBox(groupBox_3);
        kcfg_minLogLevel->addItem(QString());
        kcfg_minLogLevel->addItem(QString());
        kcfg_minLogLevel->addItem(QString());
        kcfg_minLogLevel->addItem(QString());
        kcfg_minLogLevel->setObjectName("kcfg_minLogLevel");

        horizontalLayout->addWidget(kcfg_minLogLevel);


        verticalLayout->addWidget(groupBox_3);

        groupBox_4 = new QGroupBox(ConfigurePageGeneral);
        groupBox_4->setObjectName("groupBox_4");
        sizePolicy.setHeightForWidth(groupBox_4->sizePolicy().hasHeightForWidth());
        groupBox_4->setSizePolicy(sizePolicy);
        horizontalLayout_2 = new QHBoxLayout(groupBox_4);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_3 = new QLabel(groupBox_4);
        label_3->setObjectName("label_3");

        horizontalLayout_2->addWidget(label_3);

        m_ComboDefaultFileSystem = new QComboBox(groupBox_4);
        m_ComboDefaultFileSystem->setObjectName("m_ComboDefaultFileSystem");

        horizontalLayout_2->addWidget(m_ComboDefaultFileSystem);


        verticalLayout->addWidget(groupBox_4);

        groupBox_5 = new QGroupBox(ConfigurePageGeneral);
        groupBox_5->setObjectName("groupBox_5");
        sizePolicy.setHeightForWidth(groupBox_5->sizePolicy().hasHeightForWidth());
        groupBox_5->setSizePolicy(sizePolicy);
        horizontalLayout_4 = new QHBoxLayout(groupBox_5);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        label_5 = new QLabel(groupBox_5);
        label_5->setObjectName("label_5");

        horizontalLayout_4->addWidget(label_5);

        radioButton = new QRadioButton(groupBox_5);
        kcfg_shredSource = new QButtonGroup(ConfigurePageGeneral);
        kcfg_shredSource->setObjectName("kcfg_shredSource");
        kcfg_shredSource->addButton(radioButton);
        radioButton->setObjectName("radioButton");

        horizontalLayout_4->addWidget(radioButton);

        radioButton_2 = new QRadioButton(groupBox_5);
        kcfg_shredSource->addButton(radioButton_2);
        radioButton_2->setObjectName("radioButton_2");

        horizontalLayout_4->addWidget(radioButton_2);


        verticalLayout->addWidget(groupBox_5);

#if QT_CONFIG(shortcut)
        label->setBuddy(kcfg_sectorAlignment);
        label_2->setBuddy(kcfg_minLogLevel);
        label_3->setBuddy(m_ComboDefaultFileSystem);
#endif // QT_CONFIG(shortcut)

        retranslateUi(ConfigurePageGeneral);

        QMetaObject::connectSlotsByName(ConfigurePageGeneral);
    } // setupUi

    void retranslateUi(QWidget *ConfigurePageGeneral)
    {
        groupBox_2->setTitle(tr2i18n("Partition Alignment", nullptr));
        kcfg_alignDefault->setText(tr2i18n("Align partitions per default", nullptr));
        label->setText(tr2i18n("Sec&tor alignment:", nullptr));
        kcfg_sectorAlignment->setSuffix(tr2i18n(" sectors", nullptr));
        groupBox_3->setTitle(tr2i18n("Logging", nullptr));
        label_2->setText(tr2i18n("Hide messa&ges below:", nullptr));
        kcfg_minLogLevel->setItemText(0, tr2i18n("Debug", nullptr));
        kcfg_minLogLevel->setItemText(1, tr2i18n("Information", nullptr));
        kcfg_minLogLevel->setItemText(2, tr2i18n("Warning", nullptr));
        kcfg_minLogLevel->setItemText(3, tr2i18n("Error", nullptr));

        groupBox_4->setTitle(tr2i18n("File Systems", nullptr));
        label_3->setText(tr2i18n("&Default file system:", nullptr));
        groupBox_5->setTitle(tr2i18n("Shredding", nullptr));
        label_5->setText(tr2i18n("Overwrite with:", nullptr));
        radioButton->setText(tr2i18n("Random data", nullptr));
        radioButton_2->setText(tr2i18n("&Zeros", nullptr));
        (void)ConfigurePageGeneral;
    } // retranslateUi

};

namespace Ui {
    class ConfigurePageGeneral: public Ui_ConfigurePageGeneral {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONFIGUREPAGEGENERAL_H

