/********************************************************************************
** Form generated from reading UI file 'editmountpointdialogwidgetbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EDITMOUNTPOINTDIALOGWIDGETBASE_H
#define UI_EDITMOUNTPOINTDIALOGWIDGETBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kmessagewidget.h"

QT_BEGIN_NAMESPACE

class Ui_EditMountPointDialogWidgetBase
{
public:
    QGridLayout *gridLayout;
    QRadioButton *m_RadioLabel;
    QSpacerItem *verticalSpacer_3;
    QLabel *m_LabelDumpFreq;
    QSpacerItem *horizontalSpacer_2;
    QSpinBox *m_SpinDumpFreq;
    QCheckBox *m_CheckNoAuto;
    QSpacerItem *horizontalSpacer;
    QCheckBox *m_CheckSync;
    QPushButton *m_ButtonMore;
    QLabel *m_LabelPassNumber;
    QPushButton *m_ButtonRemove;
    KMessageWidget *m_PathMessage;
    QSpinBox *m_SpinPassNumber;
    QLabel *m_LabelNameValue;
    QLabel *m_LabelPath;
    QCheckBox *m_CheckUsers;
    QLabel *m_LabelType;
    QRadioButton *m_RadioUUID;
    QPushButton *m_ButtonSelect;
    QRadioButton *m_RadioDeviceNode;
    QCheckBox *m_CheckNoAtime;
    QSpacerItem *horizontalSpacer_3;
    QCheckBox *m_CheckNoExec;
    QLabel *m_LabelTypeValue;
    QCheckBox *m_CheckRelAtime;
    QCheckBox *m_CheckNoFail;
    QFrame *line;
    QCheckBox *m_CheckNoDirAtime;
    QComboBox *m_EditPath;
    QLabel *label;
    QCheckBox *m_CheckReadOnly;
    QLabel *m_LabelOptions;

    void setupUi(QWidget *EditMountPointDialogWidgetBase)
    {
        if (EditMountPointDialogWidgetBase->objectName().isEmpty())
            EditMountPointDialogWidgetBase->setObjectName("EditMountPointDialogWidgetBase");
        EditMountPointDialogWidgetBase->resize(674, 429);
        gridLayout = new QGridLayout(EditMountPointDialogWidgetBase);
        gridLayout->setObjectName("gridLayout");
        m_RadioLabel = new QRadioButton(EditMountPointDialogWidgetBase);
        m_RadioLabel->setObjectName("m_RadioLabel");

        gridLayout->addWidget(m_RadioLabel, 2, 3, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        gridLayout->addItem(verticalSpacer_3, 13, 0, 1, 7);

        m_LabelDumpFreq = new QLabel(EditMountPointDialogWidgetBase);
        m_LabelDumpFreq->setObjectName("m_LabelDumpFreq");
        m_LabelDumpFreq->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(m_LabelDumpFreq, 12, 0, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(70, 23, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 12, 2, 1, 1);

        m_SpinDumpFreq = new QSpinBox(EditMountPointDialogWidgetBase);
        m_SpinDumpFreq->setObjectName("m_SpinDumpFreq");

        gridLayout->addWidget(m_SpinDumpFreq, 12, 1, 1, 1);

        m_CheckNoAuto = new QCheckBox(EditMountPointDialogWidgetBase);
        m_CheckNoAuto->setObjectName("m_CheckNoAuto");

        gridLayout->addWidget(m_CheckNoAuto, 7, 1, 1, 2);

        horizontalSpacer = new QSpacerItem(195, 22, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 11, 3, 1, 3);

        m_CheckSync = new QCheckBox(EditMountPointDialogWidgetBase);
        m_CheckSync->setObjectName("m_CheckSync");

        gridLayout->addWidget(m_CheckSync, 8, 1, 1, 2);

        m_ButtonMore = new QPushButton(EditMountPointDialogWidgetBase);
        m_ButtonMore->setObjectName("m_ButtonMore");

        gridLayout->addWidget(m_ButtonMore, 11, 6, 1, 1);

        m_LabelPassNumber = new QLabel(EditMountPointDialogWidgetBase);
        m_LabelPassNumber->setObjectName("m_LabelPassNumber");
        m_LabelPassNumber->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(m_LabelPassNumber, 12, 3, 1, 1);

        m_ButtonRemove = new QPushButton(EditMountPointDialogWidgetBase);
        m_ButtonRemove->setObjectName("m_ButtonRemove");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_ButtonRemove->sizePolicy().hasHeightForWidth());
        m_ButtonRemove->setSizePolicy(sizePolicy);

        gridLayout->addWidget(m_ButtonRemove, 3, 6, 1, 1);

        m_PathMessage = new KMessageWidget(EditMountPointDialogWidgetBase);
        m_PathMessage->setObjectName("m_PathMessage");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(m_PathMessage->sizePolicy().hasHeightForWidth());
        m_PathMessage->setSizePolicy(sizePolicy1);
        m_PathMessage->setCloseButtonVisible(false);
        m_PathMessage->setMessageType(KMessageWidget::Error);

        gridLayout->addWidget(m_PathMessage, 4, 1, 1, 3);

        m_SpinPassNumber = new QSpinBox(EditMountPointDialogWidgetBase);
        m_SpinPassNumber->setObjectName("m_SpinPassNumber");

        gridLayout->addWidget(m_SpinPassNumber, 12, 4, 1, 1);

        m_LabelNameValue = new QLabel(EditMountPointDialogWidgetBase);
        m_LabelNameValue->setObjectName("m_LabelNameValue");
        QFont font;
        font.setBold(true);
        m_LabelNameValue->setFont(font);
        m_LabelNameValue->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(m_LabelNameValue, 0, 0, 1, 7);

        m_LabelPath = new QLabel(EditMountPointDialogWidgetBase);
        m_LabelPath->setObjectName("m_LabelPath");
        m_LabelPath->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(m_LabelPath, 3, 0, 1, 1);

        m_CheckUsers = new QCheckBox(EditMountPointDialogWidgetBase);
        m_CheckUsers->setObjectName("m_CheckUsers");

        gridLayout->addWidget(m_CheckUsers, 6, 3, 1, 4);

        m_LabelType = new QLabel(EditMountPointDialogWidgetBase);
        m_LabelType->setObjectName("m_LabelType");
        m_LabelType->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(m_LabelType, 5, 0, 1, 1);

        m_RadioUUID = new QRadioButton(EditMountPointDialogWidgetBase);
        m_RadioUUID->setObjectName("m_RadioUUID");

        gridLayout->addWidget(m_RadioUUID, 2, 2, 1, 1);

        m_ButtonSelect = new QPushButton(EditMountPointDialogWidgetBase);
        m_ButtonSelect->setObjectName("m_ButtonSelect");
        sizePolicy.setHeightForWidth(m_ButtonSelect->sizePolicy().hasHeightForWidth());
        m_ButtonSelect->setSizePolicy(sizePolicy);

        gridLayout->addWidget(m_ButtonSelect, 3, 4, 1, 1);

        m_RadioDeviceNode = new QRadioButton(EditMountPointDialogWidgetBase);
        m_RadioDeviceNode->setObjectName("m_RadioDeviceNode");
        m_RadioDeviceNode->setChecked(true);

        gridLayout->addWidget(m_RadioDeviceNode, 2, 1, 1, 1);

        m_CheckNoAtime = new QCheckBox(EditMountPointDialogWidgetBase);
        m_CheckNoAtime->setObjectName("m_CheckNoAtime");

        gridLayout->addWidget(m_CheckNoAtime, 7, 3, 1, 3);

        horizontalSpacer_3 = new QSpacerItem(135, 23, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_3, 12, 5, 1, 2);

        m_CheckNoExec = new QCheckBox(EditMountPointDialogWidgetBase);
        m_CheckNoExec->setObjectName("m_CheckNoExec");

        gridLayout->addWidget(m_CheckNoExec, 9, 1, 1, 2);

        m_LabelTypeValue = new QLabel(EditMountPointDialogWidgetBase);
        m_LabelTypeValue->setObjectName("m_LabelTypeValue");

        gridLayout->addWidget(m_LabelTypeValue, 5, 1, 1, 2);

        m_CheckRelAtime = new QCheckBox(EditMountPointDialogWidgetBase);
        m_CheckRelAtime->setObjectName("m_CheckRelAtime");

        gridLayout->addWidget(m_CheckRelAtime, 9, 3, 1, 4);

        m_CheckNoFail = new QCheckBox(EditMountPointDialogWidgetBase);
        m_CheckNoFail->setObjectName("m_CheckNoFail");

        gridLayout->addWidget(m_CheckNoFail, 10, 1, 1, 2);

        line = new QFrame(EditMountPointDialogWidgetBase);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line, 1, 0, 1, 7);

        m_CheckNoDirAtime = new QCheckBox(EditMountPointDialogWidgetBase);
        m_CheckNoDirAtime->setObjectName("m_CheckNoDirAtime");

        gridLayout->addWidget(m_CheckNoDirAtime, 8, 3, 1, 4);

        m_EditPath = new QComboBox(EditMountPointDialogWidgetBase);
        m_EditPath->setObjectName("m_EditPath");

        gridLayout->addWidget(m_EditPath, 3, 1, 1, 3);

        label = new QLabel(EditMountPointDialogWidgetBase);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label, 2, 0, 1, 1);

        m_CheckReadOnly = new QCheckBox(EditMountPointDialogWidgetBase);
        m_CheckReadOnly->setObjectName("m_CheckReadOnly");

        gridLayout->addWidget(m_CheckReadOnly, 6, 1, 1, 2);

        m_LabelOptions = new QLabel(EditMountPointDialogWidgetBase);
        m_LabelOptions->setObjectName("m_LabelOptions");
        m_LabelOptions->setAlignment(Qt::AlignRight|Qt::AlignTop|Qt::AlignTrailing);

        gridLayout->addWidget(m_LabelOptions, 6, 0, 1, 1);

#if QT_CONFIG(shortcut)
        m_LabelDumpFreq->setBuddy(m_SpinDumpFreq);
        m_LabelPassNumber->setBuddy(m_SpinPassNumber);
#endif // QT_CONFIG(shortcut)

        retranslateUi(EditMountPointDialogWidgetBase);

        QMetaObject::connectSlotsByName(EditMountPointDialogWidgetBase);
    } // setupUi

    void retranslateUi(QWidget *EditMountPointDialogWidgetBase)
    {
        m_RadioLabel->setText(tr2i18n("&Label", nullptr));
        m_LabelDumpFreq->setText(tr2i18n("Dump &Frequency:", nullptr));
        m_CheckNoAuto->setText(tr2i18n("No automatic mount", nullptr));
        m_CheckSync->setText(tr2i18n("Synchronous access", nullptr));
        m_ButtonMore->setText(tr2i18n("More...", nullptr));
        m_LabelPassNumber->setText(tr2i18n("Pass &Number:", nullptr));
        m_ButtonRemove->setText(tr2i18n("Remove", nullptr));
        m_PathMessage->setText(tr2i18n("A valid path is required.", nullptr));
        m_LabelNameValue->setText(QString());
        m_LabelPath->setText(tr2i18n("Path:", nullptr));
        m_CheckUsers->setText(tr2i18n("Users can mount and unmount", nullptr));
        m_LabelType->setText(tr2i18n("Type:", nullptr));
        m_RadioUUID->setText(tr2i18n("UU&ID", nullptr));
        m_ButtonSelect->setText(tr2i18n("Select...", nullptr));
        m_RadioDeviceNode->setText(tr2i18n("De&vice Node", nullptr));
        m_CheckNoAtime->setText(tr2i18n("No update of file access times", nullptr));
        m_CheckNoExec->setText(tr2i18n("No binary execution", nullptr));
        m_LabelTypeValue->setText(QString());
        m_CheckRelAtime->setText(tr2i18n("Update access times relative to modification", nullptr));
        m_CheckNoFail->setText(tr2i18n("Don't prevent the system from booting if not mountable", nullptr));
        m_CheckNoDirAtime->setText(tr2i18n("No update of directory access times", nullptr));
        label->setText(tr2i18n("Identify by:", nullptr));
        m_CheckReadOnly->setText(tr2i18n("Read-only", nullptr));
        m_LabelOptions->setText(tr2i18n("Options:", nullptr));
        (void)EditMountPointDialogWidgetBase;
    } // retranslateUi

};

namespace Ui {
    class EditMountPointDialogWidgetBase: public Ui_EditMountPointDialogWidgetBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EDITMOUNTPOINTDIALOGWIDGETBASE_H

