/********************************************************************************
** Form generated from reading UI file 'listdevicesbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LISTDEVICESBASE_H
#define UI_LISTDEVICESBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ListDevicesBase
{
public:
    QVBoxLayout *verticalLayout;
    QListWidget *m_ListDevices;

    void setupUi(QWidget *ListDevicesBase)
    {
        if (ListDevicesBase->objectName().isEmpty())
            ListDevicesBase->setObjectName("ListDevicesBase");
        ListDevicesBase->resize(255, 396);
        verticalLayout = new QVBoxLayout(ListDevicesBase);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout->setObjectName("verticalLayout");
        m_ListDevices = new QListWidget(ListDevicesBase);
        m_ListDevices->setObjectName("m_ListDevices");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_ListDevices->sizePolicy().hasHeightForWidth());
        m_ListDevices->setSizePolicy(sizePolicy);
        m_ListDevices->setContextMenuPolicy(Qt::CustomContextMenu);
        m_ListDevices->setIconSize(QSize(32, 32));

        verticalLayout->addWidget(m_ListDevices);


        retranslateUi(ListDevicesBase);

        QMetaObject::connectSlotsByName(ListDevicesBase);
    } // setupUi

    void retranslateUi(QWidget *ListDevicesBase)
    {
        (void)ListDevicesBase;
    } // retranslateUi

};

namespace Ui {
    class ListDevicesBase: public Ui_ListDevicesBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LISTDEVICESBASE_H

