/********************************************************************************
** Form generated from reading UI file 'listphysicalvolumesbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LISTPHYSICALVOLUMESBASE_H
#define UI_LISTPHYSICALVOLUMESBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ListPhysicalVolumesBase
{
public:
    QListWidget *m_ListPhysicalVolumes;

    void setupUi(QWidget *ListPhysicalVolumesBase)
    {
        if (ListPhysicalVolumesBase->objectName().isEmpty())
            ListPhysicalVolumesBase->setObjectName("ListPhysicalVolumesBase");
        ListPhysicalVolumesBase->resize(249, 300);
        m_ListPhysicalVolumes = new QListWidget(ListPhysicalVolumesBase);
        m_ListPhysicalVolumes->setObjectName("m_ListPhysicalVolumes");
        m_ListPhysicalVolumes->setGeometry(QRect(0, 0, 251, 301));

        retranslateUi(ListPhysicalVolumesBase);

        QMetaObject::connectSlotsByName(ListPhysicalVolumesBase);
    } // setupUi

    void retranslateUi(QWidget *ListPhysicalVolumesBase)
    {
        (void)ListPhysicalVolumesBase;
    } // retranslateUi

};

namespace Ui {
    class ListPhysicalVolumesBase: public Ui_ListPhysicalVolumesBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LISTPHYSICALVOLUMESBASE_H

