/********************************************************************************
** Form generated from reading UI file 'devicepropswidgetbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DEVICEPROPSWIDGETBASE_H
#define UI_DEVICEPROPSWIDGETBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "gui/parttablewidget.h"

QT_BEGIN_NAMESPACE

class Ui_DevicePropsWidgetBase
{
public:
    QGridLayout *gridLayout;
    QLabel *m_LabelTextLogicalSectorSize;
    QLabel *m_LabelTextPrimariesMax;
    QLabel *m_LabelTextTotalSectors;
    QHBoxLayout *horizontalLayout;
    QLabel *m_LabelSmartStatusIcon;
    QLabel *m_LabelSmartStatusText;
    QPushButton *m_ButtonSmartMore;
    QLabel *m_LabelTextCapacity;
    QLabel *m_LabelCapacity;
    QLabel *m_LabelTextSmartStatus;
    QLabel *m_LabelLogicalSectorSize;
    QSpacerItem *verticalSpacer;
    QSpacerItem *verticalSpacer_2;
    QLabel *m_LabelPhysicalSectorSize;
    QLabel *m_LabelType;
    QFrame *line_2;
    QFrame *line;
    QLabel *m_LabelTextPhysicalSectorSize;
    QFrame *line_4;
    PartTableWidget *m_PartTableWidget;
    QLabel *m_LabelPrimariesMax;
    QLabel *m_LabelTotalSectors;
    QFrame *line_3;
    QLabel *m_LabelTextType;

    void setupUi(QWidget *DevicePropsWidgetBase)
    {
        if (DevicePropsWidgetBase->objectName().isEmpty())
            DevicePropsWidgetBase->setObjectName("DevicePropsWidgetBase");
        DevicePropsWidgetBase->resize(451, 446);
        gridLayout = new QGridLayout(DevicePropsWidgetBase);
        gridLayout->setObjectName("gridLayout");
        m_LabelTextLogicalSectorSize = new QLabel(DevicePropsWidgetBase);
        m_LabelTextLogicalSectorSize->setObjectName("m_LabelTextLogicalSectorSize");
        m_LabelTextLogicalSectorSize->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(m_LabelTextLogicalSectorSize, 7, 0, 1, 1);

        m_LabelTextPrimariesMax = new QLabel(DevicePropsWidgetBase);
        m_LabelTextPrimariesMax->setObjectName("m_LabelTextPrimariesMax");
        m_LabelTextPrimariesMax->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(m_LabelTextPrimariesMax, 10, 0, 1, 1);

        m_LabelTextTotalSectors = new QLabel(DevicePropsWidgetBase);
        m_LabelTextTotalSectors->setObjectName("m_LabelTextTotalSectors");
        m_LabelTextTotalSectors->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(m_LabelTextTotalSectors, 5, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        m_LabelSmartStatusIcon = new QLabel(DevicePropsWidgetBase);
        m_LabelSmartStatusIcon->setObjectName("m_LabelSmartStatusIcon");
        m_LabelSmartStatusIcon->setMaximumSize(QSize(16, 16777215));

        horizontalLayout->addWidget(m_LabelSmartStatusIcon);

        m_LabelSmartStatusText = new QLabel(DevicePropsWidgetBase);
        m_LabelSmartStatusText->setObjectName("m_LabelSmartStatusText");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(2);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_LabelSmartStatusText->sizePolicy().hasHeightForWidth());
        m_LabelSmartStatusText->setSizePolicy(sizePolicy);
        m_LabelSmartStatusText->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByKeyboard|Qt::TextInteractionFlag::TextSelectableByMouse);

        horizontalLayout->addWidget(m_LabelSmartStatusText);

        m_ButtonSmartMore = new QPushButton(DevicePropsWidgetBase);
        m_ButtonSmartMore->setObjectName("m_ButtonSmartMore");

        horizontalLayout->addWidget(m_ButtonSmartMore);


        gridLayout->addLayout(horizontalLayout, 12, 1, 1, 1);

        m_LabelTextCapacity = new QLabel(DevicePropsWidgetBase);
        m_LabelTextCapacity->setObjectName("m_LabelTextCapacity");
        m_LabelTextCapacity->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(m_LabelTextCapacity, 4, 0, 1, 1);

        m_LabelCapacity = new QLabel(DevicePropsWidgetBase);
        m_LabelCapacity->setObjectName("m_LabelCapacity");
        m_LabelCapacity->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByKeyboard|Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout->addWidget(m_LabelCapacity, 4, 1, 1, 1);

        m_LabelTextSmartStatus = new QLabel(DevicePropsWidgetBase);
        m_LabelTextSmartStatus->setObjectName("m_LabelTextSmartStatus");
        m_LabelTextSmartStatus->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(m_LabelTextSmartStatus, 12, 0, 1, 1);

        m_LabelLogicalSectorSize = new QLabel(DevicePropsWidgetBase);
        m_LabelLogicalSectorSize->setObjectName("m_LabelLogicalSectorSize");
        m_LabelLogicalSectorSize->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByKeyboard|Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout->addWidget(m_LabelLogicalSectorSize, 7, 1, 1, 1);

        verticalSpacer = new QSpacerItem(439, 17, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer, 1, 0, 1, 2);

        verticalSpacer_2 = new QSpacerItem(439, 14, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_2, 13, 0, 1, 2);

        m_LabelPhysicalSectorSize = new QLabel(DevicePropsWidgetBase);
        m_LabelPhysicalSectorSize->setObjectName("m_LabelPhysicalSectorSize");
        m_LabelPhysicalSectorSize->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByKeyboard|Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout->addWidget(m_LabelPhysicalSectorSize, 8, 1, 1, 1);

        m_LabelType = new QLabel(DevicePropsWidgetBase);
        m_LabelType->setObjectName("m_LabelType");
        m_LabelType->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByKeyboard|Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout->addWidget(m_LabelType, 2, 1, 1, 1);

        line_2 = new QFrame(DevicePropsWidgetBase);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line_2, 6, 0, 1, 2);

        line = new QFrame(DevicePropsWidgetBase);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line, 3, 0, 1, 2);

        m_LabelTextPhysicalSectorSize = new QLabel(DevicePropsWidgetBase);
        m_LabelTextPhysicalSectorSize->setObjectName("m_LabelTextPhysicalSectorSize");
        m_LabelTextPhysicalSectorSize->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(m_LabelTextPhysicalSectorSize, 8, 0, 1, 1);

        line_4 = new QFrame(DevicePropsWidgetBase);
        line_4->setObjectName("line_4");
        line_4->setFrameShape(QFrame::Shape::HLine);
        line_4->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line_4, 11, 0, 1, 2);

        m_PartTableWidget = new PartTableWidget(DevicePropsWidgetBase);
        m_PartTableWidget->setObjectName("m_PartTableWidget");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(m_PartTableWidget->sizePolicy().hasHeightForWidth());
        m_PartTableWidget->setSizePolicy(sizePolicy1);
        m_PartTableWidget->setMinimumSize(QSize(0, 60));
        m_PartTableWidget->setMaximumSize(QSize(16777215, 60));
        m_PartTableWidget->setContextMenuPolicy(Qt::ContextMenuPolicy::CustomContextMenu);

        gridLayout->addWidget(m_PartTableWidget, 0, 0, 1, 2);

        m_LabelPrimariesMax = new QLabel(DevicePropsWidgetBase);
        m_LabelPrimariesMax->setObjectName("m_LabelPrimariesMax");
        m_LabelPrimariesMax->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByKeyboard|Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout->addWidget(m_LabelPrimariesMax, 10, 1, 1, 1);

        m_LabelTotalSectors = new QLabel(DevicePropsWidgetBase);
        m_LabelTotalSectors->setObjectName("m_LabelTotalSectors");
        m_LabelTotalSectors->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByKeyboard|Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout->addWidget(m_LabelTotalSectors, 5, 1, 1, 1);

        line_3 = new QFrame(DevicePropsWidgetBase);
        line_3->setObjectName("line_3");
        line_3->setFrameShape(QFrame::Shape::HLine);
        line_3->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line_3, 9, 0, 1, 2);

        m_LabelTextType = new QLabel(DevicePropsWidgetBase);
        m_LabelTextType->setObjectName("m_LabelTextType");
        m_LabelTextType->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(m_LabelTextType, 2, 0, 1, 1);


        retranslateUi(DevicePropsWidgetBase);

        QMetaObject::connectSlotsByName(DevicePropsWidgetBase);
    } // setupUi

    void retranslateUi(QWidget *DevicePropsWidgetBase)
    {
        m_LabelTextLogicalSectorSize->setText(tr2i18n("Logical sector size:", nullptr));
        m_LabelTextPrimariesMax->setText(tr2i18n("Primaries/Max:", nullptr));
        m_LabelTextTotalSectors->setText(tr2i18n("Total sectors:", nullptr));
        m_LabelSmartStatusIcon->setText(QString());
        m_LabelSmartStatusText->setText(QString());
        m_ButtonSmartMore->setText(tr2i18n("More...", nullptr));
        m_LabelTextCapacity->setText(tr2i18n("Capacity:", nullptr));
        m_LabelCapacity->setText(QString());
        m_LabelTextSmartStatus->setText(tr2i18n("SMART status:", nullptr));
        m_LabelLogicalSectorSize->setText(QString());
        m_LabelPhysicalSectorSize->setText(QString());
        m_LabelType->setText(QString());
        m_LabelTextPhysicalSectorSize->setText(tr2i18n("Physical sector size:", nullptr));
        m_LabelPrimariesMax->setText(QString());
        m_LabelTotalSectors->setText(QString());
        m_LabelTextType->setText(tr2i18n("Partition table:", nullptr));
        (void)DevicePropsWidgetBase;
    } // retranslateUi

};

namespace Ui {
    class DevicePropsWidgetBase: public Ui_DevicePropsWidgetBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DEVICEPROPSWIDGETBASE_H

