/********************************************************************************
** Form generated from reading UI file 'partitionmanagerwidgetbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PARTITIONMANAGERWIDGETBASE_H
#define UI_PARTITIONMANAGERWIDGETBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "gui/parttablewidget.h"

QT_BEGIN_NAMESPACE

class Ui_PartitionManagerWidgetBase
{
public:
    QVBoxLayout *verticalLayout;
    PartTableWidget *m_PartTableWidget;
    QTreeWidget *m_TreePartitions;

    void setupUi(QWidget *PartitionManagerWidgetBase)
    {
        if (PartitionManagerWidgetBase->objectName().isEmpty())
            PartitionManagerWidgetBase->setObjectName("PartitionManagerWidgetBase");
        PartitionManagerWidgetBase->resize(819, 531);
        verticalLayout = new QVBoxLayout(PartitionManagerWidgetBase);
        verticalLayout->setSpacing(0);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout->setObjectName("verticalLayout");
        m_PartTableWidget = new PartTableWidget(PartitionManagerWidgetBase);
        m_PartTableWidget->setObjectName("m_PartTableWidget");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_PartTableWidget->sizePolicy().hasHeightForWidth());
        m_PartTableWidget->setSizePolicy(sizePolicy);
        m_PartTableWidget->setMinimumSize(QSize(0, 72));
        m_PartTableWidget->setMaximumSize(QSize(16777215, 80));
        m_PartTableWidget->setContextMenuPolicy(Qt::CustomContextMenu);

        verticalLayout->addWidget(m_PartTableWidget);

        m_TreePartitions = new QTreeWidget(PartitionManagerWidgetBase);
        m_TreePartitions->setObjectName("m_TreePartitions");
        m_TreePartitions->setContextMenuPolicy(Qt::CustomContextMenu);
        m_TreePartitions->setAlternatingRowColors(true);
        m_TreePartitions->setIconSize(QSize(32, 32));
        m_TreePartitions->setRootIsDecorated(false);
        m_TreePartitions->setUniformRowHeights(true);
        m_TreePartitions->setItemsExpandable(false);

        verticalLayout->addWidget(m_TreePartitions);


        retranslateUi(PartitionManagerWidgetBase);

        QMetaObject::connectSlotsByName(PartitionManagerWidgetBase);
    } // setupUi

    void retranslateUi(QWidget *PartitionManagerWidgetBase)
    {
        PartitionManagerWidgetBase->setWindowTitle(tr2i18n("KDE Partition Manager", "@title:window"));
        QTreeWidgetItem *___qtreewidgetitem = m_TreePartitions->headerItem();
        ___qtreewidgetitem->setText(13, tr2i18n("Flags", nullptr));
        ___qtreewidgetitem->setText(12, tr2i18n("Number of Sectors", nullptr));
        ___qtreewidgetitem->setText(11, tr2i18n("Last Sector", nullptr));
        ___qtreewidgetitem->setText(10, tr2i18n("First Sector", nullptr));
        ___qtreewidgetitem->setText(9, tr2i18n("Available", nullptr));
        ___qtreewidgetitem->setText(8, tr2i18n("Used", nullptr));
        ___qtreewidgetitem->setText(7, tr2i18n("Size", nullptr));
        ___qtreewidgetitem->setText(6, tr2i18n("Partition UUID", nullptr));
        ___qtreewidgetitem->setText(5, tr2i18n("Partition Name", nullptr));
        ___qtreewidgetitem->setText(4, tr2i18n("UUID", nullptr));
        ___qtreewidgetitem->setText(3, tr2i18n("Label", nullptr));
        ___qtreewidgetitem->setText(2, tr2i18n("Mount Point", nullptr));
        ___qtreewidgetitem->setText(1, tr2i18n("Type", nullptr));
        ___qtreewidgetitem->setText(0, tr2i18n("Partition", nullptr));
    } // retranslateUi

};

namespace Ui {
    class PartitionManagerWidgetBase: public Ui_PartitionManagerWidgetBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PARTITIONMANAGERWIDGETBASE_H

