/****************************************************************************
** Meta object code from reading C++ file 'partitionmanagerwidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../partitionmanager-26.04.3/src/gui/partitionmanagerwidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'partitionmanagerwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22PartitionManagerWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto PartitionManagerWidget::qt_create_metaobjectdata<qt_meta_tag_ZN22PartitionManagerWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PartitionManagerWidget",
        "selectedPartitionChanged",
        "",
        "const Partition*",
        "contextMenuRequested",
        "QPoint",
        "deviceDoubleClicked",
        "const Device*",
        "partitionDoubleClicked",
        "p",
        "on_m_TreePartitions_currentItemChanged",
        "QTreeWidgetItem*",
        "current",
        "previous",
        "on_m_TreePartitions_customContextMenuRequested",
        "pos",
        "on_m_TreePartitions_itemDoubleClicked",
        "item",
        "on_m_PartTableWidget_itemSelectionChanged",
        "PartWidget*",
        "on_m_PartTableWidget_customContextMenuRequested",
        "on_m_PartTableWidget_itemDoubleClicked"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'selectedPartitionChanged'
        QtMocHelpers::SignalData<void(const Partition *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'contextMenuRequested'
        QtMocHelpers::SignalData<void(const QPoint &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'deviceDoubleClicked'
        QtMocHelpers::SignalData<void(const Device *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Signal 'partitionDoubleClicked'
        QtMocHelpers::SignalData<void(const Partition *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 9 },
        }}),
        // Slot 'on_m_TreePartitions_currentItemChanged'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *, QTreeWidgetItem *)>(10, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { 0x80000000 | 11, 13 },
        }}),
        // Slot 'on_m_TreePartitions_customContextMenuRequested'
        QtMocHelpers::SlotData<void(const QPoint &)>(14, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 5, 15 },
        }}),
        // Slot 'on_m_TreePartitions_itemDoubleClicked'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *, int)>(16, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 11, 17 }, { QMetaType::Int, 2 },
        }}),
        // Slot 'on_m_PartTableWidget_itemSelectionChanged'
        QtMocHelpers::SlotData<void(PartWidget *)>(18, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 19, 17 },
        }}),
        // Slot 'on_m_PartTableWidget_customContextMenuRequested'
        QtMocHelpers::SlotData<void(const QPoint &)>(20, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 5, 15 },
        }}),
        // Slot 'on_m_PartTableWidget_itemDoubleClicked'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PartitionManagerWidget, qt_meta_tag_ZN22PartitionManagerWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PartitionManagerWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22PartitionManagerWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22PartitionManagerWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22PartitionManagerWidgetE_t>.metaTypes,
    nullptr
} };

void PartitionManagerWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PartitionManagerWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->selectedPartitionChanged((*reinterpret_cast<std::add_pointer_t<const Partition*>>(_a[1]))); break;
        case 1: _t->contextMenuRequested((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 2: _t->deviceDoubleClicked((*reinterpret_cast<std::add_pointer_t<const Device*>>(_a[1]))); break;
        case 3: _t->partitionDoubleClicked((*reinterpret_cast<std::add_pointer_t<const Partition*>>(_a[1]))); break;
        case 4: _t->on_m_TreePartitions_currentItemChanged((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[2]))); break;
        case 5: _t->on_m_TreePartitions_customContextMenuRequested((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 6: _t->on_m_TreePartitions_itemDoubleClicked((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 7: _t->on_m_PartTableWidget_itemSelectionChanged((*reinterpret_cast<std::add_pointer_t<PartWidget*>>(_a[1]))); break;
        case 8: _t->on_m_PartTableWidget_customContextMenuRequested((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 9: _t->on_m_PartTableWidget_itemDoubleClicked(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PartitionManagerWidget::*)(const Partition * )>(_a, &PartitionManagerWidget::selectedPartitionChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PartitionManagerWidget::*)(const QPoint & )>(_a, &PartitionManagerWidget::contextMenuRequested, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PartitionManagerWidget::*)(const Device * )>(_a, &PartitionManagerWidget::deviceDoubleClicked, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PartitionManagerWidget::*)(const Partition * )>(_a, &PartitionManagerWidget::partitionDoubleClicked, 3))
            return;
    }
}

const QMetaObject *PartitionManagerWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PartitionManagerWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22PartitionManagerWidgetE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::PartitionManagerWidgetBase"))
        return static_cast< Ui::PartitionManagerWidgetBase*>(this);
    return QWidget::qt_metacast(_clname);
}

int PartitionManagerWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void PartitionManagerWidget::selectedPartitionChanged(const Partition * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PartitionManagerWidget::contextMenuRequested(const QPoint & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void PartitionManagerWidget::deviceDoubleClicked(const Device * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void PartitionManagerWidget::partitionDoubleClicked(const Partition * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
