/********************************************************************************
** Form generated from reading UI file 'applyprogressdialogwidgetbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_APPLYPROGRESSDIALOGWIDGETBASE_H
#define UI_APPLYPROGRESSDIALOGWIDGETBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ApplyProgressDialogWidgetBase
{
public:
    QVBoxLayout *verticalLayout;
    QTreeWidget *m_TreeTasks;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout;
    QLabel *m_LabelTime;
    QVBoxLayout *m_MainLayout;
    QProgressBar *m_ProgressSub;
    QLabel *m_LabelStatus;
    QProgressBar *m_ProgressTotal;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QWidget *ApplyProgressDialogWidgetBase)
    {
        if (ApplyProgressDialogWidgetBase->objectName().isEmpty())
            ApplyProgressDialogWidgetBase->setObjectName("ApplyProgressDialogWidgetBase");
        ApplyProgressDialogWidgetBase->resize(732, 320);
        ApplyProgressDialogWidgetBase->setMinimumSize(QSize(720, 320));
        verticalLayout = new QVBoxLayout(ApplyProgressDialogWidgetBase);
        verticalLayout->setObjectName("verticalLayout");
        m_TreeTasks = new QTreeWidget(ApplyProgressDialogWidgetBase);
        m_TreeTasks->setObjectName("m_TreeTasks");
        m_TreeTasks->setSelectionMode(QAbstractItemView::NoSelection);
        m_TreeTasks->setWordWrap(true);
        m_TreeTasks->setColumnCount(2);
        m_TreeTasks->header()->setStretchLastSection(true);

        verticalLayout->addWidget(m_TreeTasks);

        verticalSpacer = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(verticalSpacer);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        m_LabelTime = new QLabel(ApplyProgressDialogWidgetBase);
        m_LabelTime->setObjectName("m_LabelTime");
        m_LabelTime->setAlignment(Qt::AlignCenter);
        m_LabelTime->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        horizontalLayout->addWidget(m_LabelTime);


        verticalLayout->addLayout(horizontalLayout);

        m_MainLayout = new QVBoxLayout();
        m_MainLayout->setObjectName("m_MainLayout");
        m_ProgressSub = new QProgressBar(ApplyProgressDialogWidgetBase);
        m_ProgressSub->setObjectName("m_ProgressSub");

        m_MainLayout->addWidget(m_ProgressSub);

        m_LabelStatus = new QLabel(ApplyProgressDialogWidgetBase);
        m_LabelStatus->setObjectName("m_LabelStatus");
        m_LabelStatus->setEnabled(true);
        m_LabelStatus->setAlignment(Qt::AlignCenter);
        m_LabelStatus->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        m_MainLayout->addWidget(m_LabelStatus);

        m_ProgressTotal = new QProgressBar(ApplyProgressDialogWidgetBase);
        m_ProgressTotal->setObjectName("m_ProgressTotal");
        m_ProgressTotal->setValue(0);

        m_MainLayout->addWidget(m_ProgressTotal);


        verticalLayout->addLayout(m_MainLayout);

        verticalSpacer_2 = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(verticalSpacer_2);


        retranslateUi(ApplyProgressDialogWidgetBase);

        QMetaObject::connectSlotsByName(ApplyProgressDialogWidgetBase);
    } // setupUi

    void retranslateUi(QWidget *ApplyProgressDialogWidgetBase)
    {
        QTreeWidgetItem *___qtreewidgetitem = m_TreeTasks->headerItem();
        ___qtreewidgetitem->setText(1, tr2i18n("Time Elapsed", nullptr));
        ___qtreewidgetitem->setText(0, tr2i18n("Operations and Jobs", nullptr));
        m_LabelTime->setText(tr2i18n("Total Time: 00:00:00", nullptr));
        m_ProgressSub->setFormat(tr2i18n("Operation: %p%", nullptr));
        m_LabelStatus->setText(tr2i18n("Status", nullptr));
        m_ProgressTotal->setFormat(tr2i18n("Total: %p%", nullptr));
        (void)ApplyProgressDialogWidgetBase;
    } // retranslateUi

};

namespace Ui {
    class ApplyProgressDialogWidgetBase: public Ui_ApplyProgressDialogWidgetBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // APPLYPROGRESSDIALOGWIDGETBASE_H

