/********************************************************************************
** Form generated from reading UI file 'partpropswidgetbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PARTPROPSWIDGETBASE_H
#define UI_PARTPROPSWIDGETBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "gui/partwidget.h"

QT_BEGIN_NAMESPACE

class Ui_PartPropsWidgetBase
{
public:
    QGridLayout *gridLayout;
    QLabel *m_LabelTextFirstSector;
    QFrame *line_5;
    QLabel *m_LabelNumSectors;
    QLabel *m_LabelTextCapacity;
    QLabel *m_LabelTextPartitionUuid;
    QLabel *m_LabelTextNoSetLabel;
    QLabel *m_LabelTextUuid;
    QLabel *m_LabelLastSector;
    QLabel *m_LabelTextLastSector;
    QFrame *line;
    QFrame *line_2;
    QLabel *m_LabelMountPoint;
    QLabel *m_LabelTextStatus;
    QLabel *m_LabelTextAvailable;
    QListWidget *m_ListFlags;
    QLabel *m_LabelUsed;
    QFrame *m_LineListFlags;
    QLabel *m_LabelStatus;
    QSpacerItem *verticalSpacer_2;
    PartWidget *m_PartWidget;
    QLabel *m_LabelTextLabel;
    QLabel *m_LabelAvailable;
    QLabel *m_LabelCapacity;
    QSpacerItem *verticalSpacer;
    QLabel *m_LabelUuid;
    QLabel *m_LabelRole;
    QLabel *m_LabelTextMountPoint;
    QLabel *m_LabelPartitionUuid;
    QLabel *m_LabelTextRole;
    QLabel *m_LabelTextDevicePath;
    QLabel *m_LabelTextNumSectors;
    QLabel *m_LabelTextPartitionLabel;
    QCheckBox *m_CheckRecreate;
    QLabel *m_LabelFirstSector;
    QLineEdit *m_EditPartitionLabel;
    QComboBox *m_ComboFileSystem;
    QLabel *m_LabelTextUsed;
    QLabel *m_LabelFileSystem;
    QLabel *m_LabelTextFlags;
    QLineEdit *m_EditLabel;
    QLabel *m_LabelDevicePath;

    void setupUi(QWidget *PartPropsWidgetBase)
    {
        if (PartPropsWidgetBase->objectName().isEmpty())
            PartPropsWidgetBase->setObjectName("PartPropsWidgetBase");
        PartPropsWidgetBase->resize(506, 710);
        gridLayout = new QGridLayout(PartPropsWidgetBase);
        gridLayout->setSpacing(4);
        gridLayout->setObjectName("gridLayout");
        m_LabelTextFirstSector = new QLabel(PartPropsWidgetBase);
        m_LabelTextFirstSector->setObjectName("m_LabelTextFirstSector");
        m_LabelTextFirstSector->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(m_LabelTextFirstSector, 19, 0, 1, 1);

        line_5 = new QFrame(PartPropsWidgetBase);
        line_5->setObjectName("line_5");
        line_5->setFrameShape(QFrame::Shape::HLine);
        line_5->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line_5, 6, 0, 1, 3);

        m_LabelNumSectors = new QLabel(PartPropsWidgetBase);
        m_LabelNumSectors->setObjectName("m_LabelNumSectors");
        m_LabelNumSectors->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByKeyboard|Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout->addWidget(m_LabelNumSectors, 21, 2, 1, 1);

        m_LabelTextCapacity = new QLabel(PartPropsWidgetBase);
        m_LabelTextCapacity->setObjectName("m_LabelTextCapacity");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(2);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_LabelTextCapacity->sizePolicy().hasHeightForWidth());
        m_LabelTextCapacity->setSizePolicy(sizePolicy);
        m_LabelTextCapacity->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(m_LabelTextCapacity, 15, 0, 1, 1);

        m_LabelTextPartitionUuid = new QLabel(PartPropsWidgetBase);
        m_LabelTextPartitionUuid->setObjectName("m_LabelTextPartitionUuid");
        m_LabelTextPartitionUuid->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(m_LabelTextPartitionUuid, 13, 0, 1, 1);

        m_LabelTextNoSetLabel = new QLabel(PartPropsWidgetBase);
        m_LabelTextNoSetLabel->setObjectName("m_LabelTextNoSetLabel");
        m_LabelTextNoSetLabel->setWordWrap(true);

        gridLayout->addWidget(m_LabelTextNoSetLabel, 4, 2, 1, 1);

        m_LabelTextUuid = new QLabel(PartPropsWidgetBase);
        m_LabelTextUuid->setObjectName("m_LabelTextUuid");
        m_LabelTextUuid->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(m_LabelTextUuid, 11, 0, 1, 1);

        m_LabelLastSector = new QLabel(PartPropsWidgetBase);
        m_LabelLastSector->setObjectName("m_LabelLastSector");
        m_LabelLastSector->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByKeyboard|Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout->addWidget(m_LabelLastSector, 20, 2, 1, 1);

        m_LabelTextLastSector = new QLabel(PartPropsWidgetBase);
        m_LabelTextLastSector->setObjectName("m_LabelTextLastSector");
        m_LabelTextLastSector->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(m_LabelTextLastSector, 20, 0, 1, 1);

        line = new QFrame(PartPropsWidgetBase);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line, 18, 0, 1, 3);

        line_2 = new QFrame(PartPropsWidgetBase);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line_2, 14, 0, 1, 3);

        m_LabelMountPoint = new QLabel(PartPropsWidgetBase);
        m_LabelMountPoint->setObjectName("m_LabelMountPoint");
        m_LabelMountPoint->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByKeyboard|Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout->addWidget(m_LabelMountPoint, 7, 2, 1, 1);

        m_LabelTextStatus = new QLabel(PartPropsWidgetBase);
        m_LabelTextStatus->setObjectName("m_LabelTextStatus");
        m_LabelTextStatus->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(m_LabelTextStatus, 10, 0, 1, 1);

        m_LabelTextAvailable = new QLabel(PartPropsWidgetBase);
        m_LabelTextAvailable->setObjectName("m_LabelTextAvailable");
        m_LabelTextAvailable->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(m_LabelTextAvailable, 16, 0, 1, 1);

        m_ListFlags = new QListWidget(PartPropsWidgetBase);
        m_ListFlags->setObjectName("m_ListFlags");
        m_ListFlags->setHorizontalScrollBarPolicy(Qt::ScrollBarPolicy::ScrollBarAlwaysOff);
        m_ListFlags->setAlternatingRowColors(true);
        m_ListFlags->setSelectionMode(QAbstractItemView::SelectionMode::NoSelection);
        m_ListFlags->setSortingEnabled(true);

        gridLayout->addWidget(m_ListFlags, 23, 2, 1, 1);

        m_LabelUsed = new QLabel(PartPropsWidgetBase);
        m_LabelUsed->setObjectName("m_LabelUsed");
        m_LabelUsed->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByKeyboard|Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout->addWidget(m_LabelUsed, 17, 2, 1, 1);

        m_LineListFlags = new QFrame(PartPropsWidgetBase);
        m_LineListFlags->setObjectName("m_LineListFlags");
        m_LineListFlags->setFrameShape(QFrame::Shape::HLine);
        m_LineListFlags->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(m_LineListFlags, 22, 0, 1, 3);

        m_LabelStatus = new QLabel(PartPropsWidgetBase);
        m_LabelStatus->setObjectName("m_LabelStatus");
        m_LabelStatus->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByKeyboard|Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout->addWidget(m_LabelStatus, 10, 2, 1, 1);

        verticalSpacer_2 = new QSpacerItem(488, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_2, 24, 0, 1, 3);

        m_PartWidget = new PartWidget(PartPropsWidgetBase);
        m_PartWidget->setObjectName("m_PartWidget");
        m_PartWidget->setMinimumSize(QSize(300, 60));
        m_PartWidget->setMaximumSize(QSize(16777215, 60));

        gridLayout->addWidget(m_PartWidget, 0, 0, 1, 3);

        m_LabelTextLabel = new QLabel(PartPropsWidgetBase);
        m_LabelTextLabel->setObjectName("m_LabelTextLabel");
        m_LabelTextLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(m_LabelTextLabel, 3, 0, 1, 1);

        m_LabelAvailable = new QLabel(PartPropsWidgetBase);
        m_LabelAvailable->setObjectName("m_LabelAvailable");
        m_LabelAvailable->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByKeyboard|Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout->addWidget(m_LabelAvailable, 16, 2, 1, 1);

        m_LabelCapacity = new QLabel(PartPropsWidgetBase);
        m_LabelCapacity->setObjectName("m_LabelCapacity");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(5);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(m_LabelCapacity->sizePolicy().hasHeightForWidth());
        m_LabelCapacity->setSizePolicy(sizePolicy1);
        m_LabelCapacity->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByKeyboard|Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout->addWidget(m_LabelCapacity, 15, 2, 1, 1);

        verticalSpacer = new QSpacerItem(478, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer, 1, 0, 1, 3);

        m_LabelUuid = new QLabel(PartPropsWidgetBase);
        m_LabelUuid->setObjectName("m_LabelUuid");
        m_LabelUuid->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByKeyboard|Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout->addWidget(m_LabelUuid, 11, 2, 1, 1);

        m_LabelRole = new QLabel(PartPropsWidgetBase);
        m_LabelRole->setObjectName("m_LabelRole");
        m_LabelRole->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByKeyboard|Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout->addWidget(m_LabelRole, 9, 2, 1, 1);

        m_LabelTextMountPoint = new QLabel(PartPropsWidgetBase);
        m_LabelTextMountPoint->setObjectName("m_LabelTextMountPoint");
        m_LabelTextMountPoint->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(m_LabelTextMountPoint, 7, 0, 1, 1);

        m_LabelPartitionUuid = new QLabel(PartPropsWidgetBase);
        m_LabelPartitionUuid->setObjectName("m_LabelPartitionUuid");
        m_LabelPartitionUuid->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByKeyboard|Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout->addWidget(m_LabelPartitionUuid, 13, 2, 1, 1);

        m_LabelTextRole = new QLabel(PartPropsWidgetBase);
        m_LabelTextRole->setObjectName("m_LabelTextRole");
        m_LabelTextRole->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(m_LabelTextRole, 9, 0, 1, 1);

        m_LabelTextDevicePath = new QLabel(PartPropsWidgetBase);
        m_LabelTextDevicePath->setObjectName("m_LabelTextDevicePath");
        m_LabelTextDevicePath->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(m_LabelTextDevicePath, 8, 0, 1, 1);

        m_LabelTextNumSectors = new QLabel(PartPropsWidgetBase);
        m_LabelTextNumSectors->setObjectName("m_LabelTextNumSectors");
        m_LabelTextNumSectors->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(m_LabelTextNumSectors, 21, 0, 1, 1);

        m_LabelTextPartitionLabel = new QLabel(PartPropsWidgetBase);
        m_LabelTextPartitionLabel->setObjectName("m_LabelTextPartitionLabel");
        m_LabelTextPartitionLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(m_LabelTextPartitionLabel, 12, 0, 1, 1);

        m_CheckRecreate = new QCheckBox(PartPropsWidgetBase);
        m_CheckRecreate->setObjectName("m_CheckRecreate");

        gridLayout->addWidget(m_CheckRecreate, 5, 2, 1, 1);

        m_LabelFirstSector = new QLabel(PartPropsWidgetBase);
        m_LabelFirstSector->setObjectName("m_LabelFirstSector");
        m_LabelFirstSector->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByKeyboard|Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout->addWidget(m_LabelFirstSector, 19, 2, 1, 1);

        m_EditPartitionLabel = new QLineEdit(PartPropsWidgetBase);
        m_EditPartitionLabel->setObjectName("m_EditPartitionLabel");

        gridLayout->addWidget(m_EditPartitionLabel, 12, 2, 1, 1);

        m_ComboFileSystem = new QComboBox(PartPropsWidgetBase);
        m_ComboFileSystem->setObjectName("m_ComboFileSystem");

        gridLayout->addWidget(m_ComboFileSystem, 2, 2, 1, 1);

        m_LabelTextUsed = new QLabel(PartPropsWidgetBase);
        m_LabelTextUsed->setObjectName("m_LabelTextUsed");
        m_LabelTextUsed->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(m_LabelTextUsed, 17, 0, 1, 1);

        m_LabelFileSystem = new QLabel(PartPropsWidgetBase);
        m_LabelFileSystem->setObjectName("m_LabelFileSystem");
        m_LabelFileSystem->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(m_LabelFileSystem, 2, 0, 1, 1);

        m_LabelTextFlags = new QLabel(PartPropsWidgetBase);
        m_LabelTextFlags->setObjectName("m_LabelTextFlags");
        m_LabelTextFlags->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTop|Qt::AlignmentFlag::AlignTrailing);

        gridLayout->addWidget(m_LabelTextFlags, 23, 0, 1, 1);

        m_EditLabel = new QLineEdit(PartPropsWidgetBase);
        m_EditLabel->setObjectName("m_EditLabel");

        gridLayout->addWidget(m_EditLabel, 3, 2, 1, 1);

        m_LabelDevicePath = new QLabel(PartPropsWidgetBase);
        m_LabelDevicePath->setObjectName("m_LabelDevicePath");
        m_LabelDevicePath->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByKeyboard|Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout->addWidget(m_LabelDevicePath, 8, 2, 1, 1);

#if QT_CONFIG(shortcut)
        m_LabelTextLabel->setBuddy(m_EditLabel);
        m_LabelFileSystem->setBuddy(m_ComboFileSystem);
        m_LabelTextFlags->setBuddy(m_ListFlags);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(m_ComboFileSystem, m_EditLabel);
        QWidget::setTabOrder(m_EditLabel, m_CheckRecreate);
        QWidget::setTabOrder(m_CheckRecreate, m_ListFlags);

        retranslateUi(PartPropsWidgetBase);

        QMetaObject::connectSlotsByName(PartPropsWidgetBase);
    } // setupUi

    void retranslateUi(QWidget *PartPropsWidgetBase)
    {
        m_LabelTextFirstSector->setText(tr2i18n("First sector:", "@label"));
        m_LabelTextCapacity->setText(tr2i18n("Size:", "@label"));
        m_LabelTextPartitionUuid->setText(tr2i18n("Partition UUID:", nullptr));
        m_LabelTextNoSetLabel->setText(tr2i18n("This file system does not support setting a label.", "@label"));
        m_LabelTextUuid->setText(tr2i18n("UUID:", "@label"));
        m_LabelTextLastSector->setText(tr2i18n("Last sector:", "@label"));
        m_LabelTextStatus->setText(tr2i18n("Status:", "@label"));
        m_LabelTextAvailable->setText(tr2i18n("Available:", "@label partition capacity available"));
        m_LabelTextLabel->setText(tr2i18n("&Label:", "@label"));
        m_LabelTextMountPoint->setText(tr2i18n("Mount point:", "@label"));
        m_LabelPartitionUuid->setText(QString());
        m_LabelTextRole->setText(tr2i18n("Partition type:", "@label"));
        m_LabelTextDevicePath->setText(tr2i18n("Device path:", nullptr));
        m_LabelTextNumSectors->setText(tr2i18n("Number of sectors:", "@label"));
        m_LabelTextPartitionLabel->setText(tr2i18n("Partition Name:", nullptr));
#if QT_CONFIG(whatsthis)
        m_CheckRecreate->setWhatsThis(tr2i18n("This will reformat the filesystem, losing all contents, but keeping the same filesystem type.", nullptr));
#endif // QT_CONFIG(whatsthis)
        m_CheckRecreate->setText(tr2i18n("Recreate existing file system", "@action:button"));
        m_EditPartitionLabel->setText(QString());
        m_LabelTextUsed->setText(tr2i18n("Used:", "@label partition capacity used"));
        m_LabelFileSystem->setText(tr2i18n("File syste&m:", "@label:listbox"));
        m_LabelTextFlags->setText(tr2i18n("&Flags:", "@label"));
        (void)PartPropsWidgetBase;
    } // retranslateUi

};

namespace Ui {
    class PartPropsWidgetBase: public Ui_PartPropsWidgetBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PARTPROPSWIDGETBASE_H

