/********************************************************************************
** Form generated from reading UI file 'sizedetailswidgetbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SIZEDETAILSWIDGETBASE_H
#define UI_SIZEDETAILSWIDGETBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "gui/formattedspinbox.h"

QT_BEGIN_NAMESPACE

class Ui_SizeDetailsWidgetBase
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *verticalSpacer_3;
    QFrame *line;
    QSpacerItem *verticalSpacer_4;
    QLabel *label_6;
    FormattedSpinBox *m_SpinFirstSector;
    QLabel *label_7;
    FormattedSpinBox *m_SpinLastSector;
    QCheckBox *m_CheckAlign;
    QSpacerItem *verticalSpacer_5;
    QFrame *line_2;
    QSpacerItem *verticalSpacer_6;

    void setupUi(QWidget *SizeDetailsWidgetBase)
    {
        if (SizeDetailsWidgetBase->objectName().isEmpty())
            SizeDetailsWidgetBase->setObjectName("SizeDetailsWidgetBase");
        SizeDetailsWidgetBase->resize(428, 211);
        gridLayout = new QGridLayout(SizeDetailsWidgetBase);
        gridLayout->setObjectName("gridLayout");
        verticalSpacer_3 = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_3, 0, 0, 1, 2);

        line = new QFrame(SizeDetailsWidgetBase);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line, 1, 0, 1, 2);

        verticalSpacer_4 = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_4, 2, 0, 1, 2);

        label_6 = new QLabel(SizeDetailsWidgetBase);
        label_6->setObjectName("label_6");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(3);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_6->sizePolicy().hasHeightForWidth());
        label_6->setSizePolicy(sizePolicy);
        label_6->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_6, 3, 0, 1, 1);

        m_SpinFirstSector = new FormattedSpinBox(SizeDetailsWidgetBase);
        m_SpinFirstSector->setObjectName("m_SpinFirstSector");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(4);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(m_SpinFirstSector->sizePolicy().hasHeightForWidth());
        m_SpinFirstSector->setSizePolicy(sizePolicy1);
        m_SpinFirstSector->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        m_SpinFirstSector->setDecimals(0);

        gridLayout->addWidget(m_SpinFirstSector, 3, 1, 1, 1);

        label_7 = new QLabel(SizeDetailsWidgetBase);
        label_7->setObjectName("label_7");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(label_7->sizePolicy().hasHeightForWidth());
        label_7->setSizePolicy(sizePolicy2);
        label_7->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_7, 4, 0, 1, 1);

        m_SpinLastSector = new FormattedSpinBox(SizeDetailsWidgetBase);
        m_SpinLastSector->setObjectName("m_SpinLastSector");
        m_SpinLastSector->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        m_SpinLastSector->setDecimals(0);

        gridLayout->addWidget(m_SpinLastSector, 4, 1, 1, 1);

        m_CheckAlign = new QCheckBox(SizeDetailsWidgetBase);
        m_CheckAlign->setObjectName("m_CheckAlign");
        m_CheckAlign->setChecked(true);

        gridLayout->addWidget(m_CheckAlign, 7, 0, 1, 2);

        verticalSpacer_5 = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_5, 8, 0, 1, 2);

        line_2 = new QFrame(SizeDetailsWidgetBase);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line_2, 5, 0, 1, 2);

        verticalSpacer_6 = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_6, 6, 0, 1, 2);

#if QT_CONFIG(shortcut)
        label_6->setBuddy(m_SpinFirstSector);
        label_7->setBuddy(m_SpinLastSector);
#endif // QT_CONFIG(shortcut)

        retranslateUi(SizeDetailsWidgetBase);

        QMetaObject::connectSlotsByName(SizeDetailsWidgetBase);
    } // setupUi

    void retranslateUi(QWidget *SizeDetailsWidgetBase)
    {
        label_6->setText(tr2i18n("First sector:", "@label:listbox"));
        label_7->setText(tr2i18n("Last sector:", "@label:listbox"));
        m_CheckAlign->setText(tr2i18n("Align partition", nullptr));
        (void)SizeDetailsWidgetBase;
    } // retranslateUi

};

namespace Ui {
    class SizeDetailsWidgetBase: public Ui_SizeDetailsWidgetBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SIZEDETAILSWIDGETBASE_H

