/********************************************************************************
** Form generated from reading UI file 'applyprogressdetailswidgetbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_APPLYPROGRESSDETAILSWIDGETBASE_H
#define UI_APPLYPROGRESSDETAILSWIDGETBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ApplyProgressDetailsWidgetBase
{
public:
    QGridLayout *gridLayout;
    QTextEdit *m_EditReport;
    QSpacerItem *horizontalSpacer;
    QPushButton *m_ButtonSave;
    QPushButton *m_ButtonBrowser;

    void setupUi(QWidget *ApplyProgressDetailsWidgetBase)
    {
        if (ApplyProgressDetailsWidgetBase->objectName().isEmpty())
            ApplyProgressDetailsWidgetBase->setObjectName("ApplyProgressDetailsWidgetBase");
        ApplyProgressDetailsWidgetBase->resize(736, 600);
        gridLayout = new QGridLayout(ApplyProgressDetailsWidgetBase);
        gridLayout->setObjectName("gridLayout");
        m_EditReport = new QTextEdit(ApplyProgressDetailsWidgetBase);
        m_EditReport->setObjectName("m_EditReport");
        m_EditReport->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        gridLayout->addWidget(m_EditReport, 0, 0, 1, 3);

        horizontalSpacer = new QSpacerItem(608, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 0, 1, 1);

        m_ButtonSave = new QPushButton(ApplyProgressDetailsWidgetBase);
        m_ButtonSave->setObjectName("m_ButtonSave");

        gridLayout->addWidget(m_ButtonSave, 1, 2, 1, 1);

        m_ButtonBrowser = new QPushButton(ApplyProgressDetailsWidgetBase);
        m_ButtonBrowser->setObjectName("m_ButtonBrowser");

        gridLayout->addWidget(m_ButtonBrowser, 1, 1, 1, 1);


        retranslateUi(ApplyProgressDetailsWidgetBase);

        QMetaObject::connectSlotsByName(ApplyProgressDetailsWidgetBase);
    } // setupUi

    void retranslateUi(QWidget *ApplyProgressDetailsWidgetBase)
    {
        m_ButtonSave->setText(tr2i18n("Save", nullptr));
        m_ButtonBrowser->setText(tr2i18n("Open in External Browser", nullptr));
        (void)ApplyProgressDetailsWidgetBase;
    } // retranslateUi

};

namespace Ui {
    class ApplyProgressDetailsWidgetBase: public Ui_ApplyProgressDetailsWidgetBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // APPLYPROGRESSDETAILSWIDGETBASE_H

