/********************************************************************************
** Form generated from reading UI file 'filesystemsupportdialogwidgetbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FILESYSTEMSUPPORTDIALOGWIDGETBASE_H
#define UI_FILESYSTEMSUPPORTDIALOGWIDGETBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_FileSystemSupportDialogWidgetBase
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QTreeWidget *m_Tree;
    QHBoxLayout *horizontalLayout;
    QPushButton *m_ButtonRescan;
    QSpacerItem *horizontalSpacer;

    void setupUi(QWidget *FileSystemSupportDialogWidgetBase)
    {
        if (FileSystemSupportDialogWidgetBase->objectName().isEmpty())
            FileSystemSupportDialogWidgetBase->setObjectName("FileSystemSupportDialogWidgetBase");
        FileSystemSupportDialogWidgetBase->resize(835, 488);
        verticalLayout = new QVBoxLayout(FileSystemSupportDialogWidgetBase);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(FileSystemSupportDialogWidgetBase);
        label->setObjectName("label");
        label->setWordWrap(true);
        label->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        verticalLayout->addWidget(label);

        m_Tree = new QTreeWidget(FileSystemSupportDialogWidgetBase);
        m_Tree->setObjectName("m_Tree");
        m_Tree->setAlternatingRowColors(true);
        m_Tree->setSelectionMode(QAbstractItemView::NoSelection);
        m_Tree->setIconSize(QSize(32, 32));
        m_Tree->setIndentation(0);
        m_Tree->setRootIsDecorated(false);
        m_Tree->setUniformRowHeights(true);
        m_Tree->setItemsExpandable(false);
        m_Tree->setWordWrap(false);
        m_Tree->setProperty("showGrid", QVariant(false));
        m_Tree->setProperty("cornerButtonEnabled", QVariant(false));

        verticalLayout->addWidget(m_Tree);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        m_ButtonRescan = new QPushButton(FileSystemSupportDialogWidgetBase);
        m_ButtonRescan->setObjectName("m_ButtonRescan");

        horizontalLayout->addWidget(m_ButtonRescan);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(FileSystemSupportDialogWidgetBase);

        QMetaObject::connectSlotsByName(FileSystemSupportDialogWidgetBase);
    } // setupUi

    void retranslateUi(QWidget *FileSystemSupportDialogWidgetBase)
    {
        label->setText(tr2i18n("This table shows which file systems are supported and which specific operations can be performed on them.\n"
"Some file systems need external tools to be installed for them to be supported. But not all operations can be performed on all file systems, even if all required tools are installed. Please see the documentation for details. ", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = m_Tree->headerItem();
        ___qtreewidgetitem->setText(12, tr2i18n("Support Tools", nullptr));
        ___qtreewidgetitem->setText(11, tr2i18n("Restore", nullptr));
        ___qtreewidgetitem->setText(10, tr2i18n("Backup", nullptr));
        ___qtreewidgetitem->setText(9, tr2i18n("Read Usage", nullptr));
        ___qtreewidgetitem->setText(8, tr2i18n("Write Label", nullptr));
        ___qtreewidgetitem->setText(7, tr2i18n("Read Label", nullptr));
        ___qtreewidgetitem->setText(6, tr2i18n("Check", nullptr));
        ___qtreewidgetitem->setText(5, tr2i18n("Copy", nullptr));
        ___qtreewidgetitem->setText(4, tr2i18n("Move", nullptr));
        ___qtreewidgetitem->setText(3, tr2i18n("Shrink", nullptr));
        ___qtreewidgetitem->setText(2, tr2i18n("Grow", nullptr));
        ___qtreewidgetitem->setText(1, tr2i18n("Create", nullptr));
        ___qtreewidgetitem->setText(0, tr2i18n("File System", nullptr));
        m_ButtonRescan->setText(tr2i18n("Rescan Support", "@action:button"));
        (void)FileSystemSupportDialogWidgetBase;
    } // retranslateUi

};

namespace Ui {
    class FileSystemSupportDialogWidgetBase: public Ui_FileSystemSupportDialogWidgetBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FILESYSTEMSUPPORTDIALOGWIDGETBASE_H

