/********************************************************************************
** Form generated from reading UI file 'listoperationsbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LISTOPERATIONSBASE_H
#define UI_LISTOPERATIONSBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ListOperationsBase
{
public:
    QVBoxLayout *verticalLayout;
    QListWidget *m_ListOperations;

    void setupUi(QWidget *ListOperationsBase)
    {
        if (ListOperationsBase->objectName().isEmpty())
            ListOperationsBase->setObjectName("ListOperationsBase");
        ListOperationsBase->resize(400, 300);
        verticalLayout = new QVBoxLayout(ListOperationsBase);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout->setObjectName("verticalLayout");
        m_ListOperations = new QListWidget(ListOperationsBase);
        m_ListOperations->setObjectName("m_ListOperations");
        m_ListOperations->setContextMenuPolicy(Qt::CustomContextMenu);
        m_ListOperations->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        m_ListOperations->setAutoScroll(false);
        m_ListOperations->setAlternatingRowColors(true);
        m_ListOperations->setSelectionMode(QAbstractItemView::NoSelection);
        m_ListOperations->setResizeMode(QListView::Adjust);
        m_ListOperations->setWordWrap(true);

        verticalLayout->addWidget(m_ListOperations);


        retranslateUi(ListOperationsBase);

        QMetaObject::connectSlotsByName(ListOperationsBase);
    } // setupUi

    void retranslateUi(QWidget *ListOperationsBase)
    {
        (void)ListOperationsBase;
    } // retranslateUi

};

namespace Ui {
    class ListOperationsBase: public Ui_ListOperationsBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LISTOPERATIONSBASE_H

