/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../partitionmanager-26.04.3/src/gui/mainwindow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10MainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto MainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN10MainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MainWindow",
        "settingsChanged",
        "",
        "scanFinished",
        "showMessageWidget",
        "hideMessageWidget",
        "on_m_PartitionManagerWidget_selectedPartitionChanged",
        "const Partition*",
        "p",
        "on_m_PartitionManagerWidget_contextMenuRequested",
        "QPoint",
        "pos",
        "on_m_PartitionManagerWidget_deviceDoubleClicked",
        "const Device*",
        "on_m_PartitionManagerWidget_partitionDoubleClicked",
        "on_m_DockInformation_dockLocationChanged",
        "Qt::DockWidgetArea",
        "on_m_OperationStack_operationsChanged",
        "on_m_OperationStack_devicesChanged",
        "on_m_DeviceScanner_finished",
        "on_m_DeviceScanner_progress",
        "device_node",
        "percent",
        "on_m_ApplyProgressDialog_finished",
        "listDevicesContextMenuRequested",
        "on_m_ListDevices_selectionChanged",
        "treeLogContextMenuRequested",
        "listOperationsContextMenuRequested"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'settingsChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scanFinished'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showMessageWidget'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hideMessageWidget'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'on_m_PartitionManagerWidget_selectedPartitionChanged'
        QtMocHelpers::SlotData<void(const Partition *)>(6, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'on_m_PartitionManagerWidget_contextMenuRequested'
        QtMocHelpers::SlotData<void(const QPoint &)>(9, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'on_m_PartitionManagerWidget_deviceDoubleClicked'
        QtMocHelpers::SlotData<void(const Device *)>(12, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
        // Slot 'on_m_PartitionManagerWidget_partitionDoubleClicked'
        QtMocHelpers::SlotData<void(const Partition *)>(14, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Slot 'on_m_DockInformation_dockLocationChanged'
        QtMocHelpers::SlotData<void(Qt::DockWidgetArea)>(15, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 16, 2 },
        }}),
        // Slot 'on_m_OperationStack_operationsChanged'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_m_OperationStack_devicesChanged'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_m_DeviceScanner_finished'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_m_DeviceScanner_progress'
        QtMocHelpers::SlotData<void(const QString &, int)>(20, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 21 }, { QMetaType::Int, 22 },
        }}),
        // Slot 'on_m_ApplyProgressDialog_finished'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'listDevicesContextMenuRequested'
        QtMocHelpers::SlotData<void(const QPoint &)>(24, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'on_m_ListDevices_selectionChanged'
        QtMocHelpers::SlotData<void(const QString &)>(25, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'treeLogContextMenuRequested'
        QtMocHelpers::SlotData<void(const QPoint &)>(26, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'listOperationsContextMenuRequested'
        QtMocHelpers::SlotData<void(const QPoint &)>(27, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MainWindow, qt_meta_tag_ZN10MainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<KXmlGuiWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10MainWindowE_t>.metaTypes,
    nullptr
} };

void MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->settingsChanged(); break;
        case 1: _t->scanFinished(); break;
        case 2: _t->showMessageWidget(); break;
        case 3: _t->hideMessageWidget(); break;
        case 4: _t->on_m_PartitionManagerWidget_selectedPartitionChanged((*reinterpret_cast<std::add_pointer_t<const Partition*>>(_a[1]))); break;
        case 5: _t->on_m_PartitionManagerWidget_contextMenuRequested((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 6: _t->on_m_PartitionManagerWidget_deviceDoubleClicked((*reinterpret_cast<std::add_pointer_t<const Device*>>(_a[1]))); break;
        case 7: _t->on_m_PartitionManagerWidget_partitionDoubleClicked((*reinterpret_cast<std::add_pointer_t<const Partition*>>(_a[1]))); break;
        case 8: _t->on_m_DockInformation_dockLocationChanged((*reinterpret_cast<std::add_pointer_t<Qt::DockWidgetArea>>(_a[1]))); break;
        case 9: _t->on_m_OperationStack_operationsChanged(); break;
        case 10: _t->on_m_OperationStack_devicesChanged(); break;
        case 11: _t->on_m_DeviceScanner_finished(); break;
        case 12: _t->on_m_DeviceScanner_progress((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 13: _t->on_m_ApplyProgressDialog_finished(); break;
        case 14: _t->listDevicesContextMenuRequested((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 15: _t->on_m_ListDevices_selectionChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->treeLogContextMenuRequested((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 17: _t->listOperationsContextMenuRequested((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)()>(_a, &MainWindow::settingsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)()>(_a, &MainWindow::scanFinished, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)()>(_a, &MainWindow::showMessageWidget, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)()>(_a, &MainWindow::hideMessageWidget, 3))
            return;
    }
}

const QMetaObject *MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::MainWindowBase"))
        return static_cast< Ui::MainWindowBase*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void MainWindow::settingsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MainWindow::scanFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void MainWindow::showMessageWidget()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void MainWindow::hideMessageWidget()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
