/********************************************************************************
** Form generated from reading UI file 'volumegroupwidgetbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_VOLUMEGROUPWIDGETBASE_H
#define UI_VOLUMEGROUPWIDGETBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "gui/listphysicalvolumes.h"

QT_BEGIN_NAMESPACE

class Ui_VolumeGroupWidgetBase
{
public:
    QGridLayout *gridLayout;
    QVBoxLayout *verticalLayout_2;
    QLineEdit *m_EditVGName;
    QLabel *m_LabelTextVGName;
    QLabel *m_LabelTextPESize;
    QLabel *m_LabelTotalSectors;
    QVBoxLayout *verticalLayout_4;
    QComboBox *m_ComboVolumeType;
    QVBoxLayout *verticalLayout;
    QSpinBox *m_SpinPESize;
    ListPhysicalVolumes *m_ListPV;
    QLabel *m_LabelTextTotalLV;
    QLabel *m_LabelTotalLV;
    QLabel *m_LabelTextVolumeType;
    QLabel *m_LabelTextTotalSize;
    QLabel *m_LabelTextTotalSectors;
    QLabel *m_LabelTotalSize;
    QLabel *m_LabelTotalUsedSize;
    QLabel *m_LabelTextTotalUsedSize;

    void setupUi(QWidget *VolumeGroupWidgetBase)
    {
        if (VolumeGroupWidgetBase->objectName().isEmpty())
            VolumeGroupWidgetBase->setObjectName("VolumeGroupWidgetBase");
        VolumeGroupWidgetBase->resize(831, 512);
        VolumeGroupWidgetBase->setMinimumSize(QSize(652, 0));
        gridLayout = new QGridLayout(VolumeGroupWidgetBase);
        gridLayout->setObjectName("gridLayout");
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        m_EditVGName = new QLineEdit(VolumeGroupWidgetBase);
        m_EditVGName->setObjectName("m_EditVGName");

        verticalLayout_2->addWidget(m_EditVGName);


        gridLayout->addLayout(verticalLayout_2, 1, 2, 1, 1);

        m_LabelTextVGName = new QLabel(VolumeGroupWidgetBase);
        m_LabelTextVGName->setObjectName("m_LabelTextVGName");
        m_LabelTextVGName->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        m_LabelTextVGName->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        gridLayout->addWidget(m_LabelTextVGName, 1, 1, 1, 1);

        m_LabelTextPESize = new QLabel(VolumeGroupWidgetBase);
        m_LabelTextPESize->setObjectName("m_LabelTextPESize");
        m_LabelTextPESize->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        m_LabelTextPESize->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        gridLayout->addWidget(m_LabelTextPESize, 3, 1, 1, 1);

        m_LabelTotalSectors = new QLabel(VolumeGroupWidgetBase);
        m_LabelTotalSectors->setObjectName("m_LabelTotalSectors");
        m_LabelTotalSectors->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        gridLayout->addWidget(m_LabelTotalSectors, 6, 2, 1, 1);

        verticalLayout_4 = new QVBoxLayout();
        verticalLayout_4->setObjectName("verticalLayout_4");
        m_ComboVolumeType = new QComboBox(VolumeGroupWidgetBase);
        m_ComboVolumeType->setObjectName("m_ComboVolumeType");

        verticalLayout_4->addWidget(m_ComboVolumeType);


        gridLayout->addLayout(verticalLayout_4, 2, 2, 1, 1);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        m_SpinPESize = new QSpinBox(VolumeGroupWidgetBase);
        m_SpinPESize->setObjectName("m_SpinPESize");
        m_SpinPESize->setMinimum(1);
        m_SpinPESize->setMaximum(1000);
        m_SpinPESize->setValue(4);

        verticalLayout->addWidget(m_SpinPESize);


        gridLayout->addLayout(verticalLayout, 3, 2, 1, 1);

        m_ListPV = new ListPhysicalVolumes(VolumeGroupWidgetBase);
        m_ListPV->setObjectName("m_ListPV");
        m_ListPV->setMinimumSize(QSize(250, 400));

        gridLayout->addWidget(m_ListPV, 1, 0, 7, 1);

        m_LabelTextTotalLV = new QLabel(VolumeGroupWidgetBase);
        m_LabelTextTotalLV->setObjectName("m_LabelTextTotalLV");
        m_LabelTextTotalLV->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        m_LabelTextTotalLV->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        gridLayout->addWidget(m_LabelTextTotalLV, 7, 1, 1, 1);

        m_LabelTotalLV = new QLabel(VolumeGroupWidgetBase);
        m_LabelTotalLV->setObjectName("m_LabelTotalLV");
        m_LabelTotalLV->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        gridLayout->addWidget(m_LabelTotalLV, 7, 2, 1, 1);

        m_LabelTextVolumeType = new QLabel(VolumeGroupWidgetBase);
        m_LabelTextVolumeType->setObjectName("m_LabelTextVolumeType");
        m_LabelTextVolumeType->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(m_LabelTextVolumeType, 2, 1, 1, 1);

        m_LabelTextTotalSize = new QLabel(VolumeGroupWidgetBase);
        m_LabelTextTotalSize->setObjectName("m_LabelTextTotalSize");
        m_LabelTextTotalSize->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        m_LabelTextTotalSize->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        gridLayout->addWidget(m_LabelTextTotalSize, 4, 1, 1, 1);

        m_LabelTextTotalSectors = new QLabel(VolumeGroupWidgetBase);
        m_LabelTextTotalSectors->setObjectName("m_LabelTextTotalSectors");
        m_LabelTextTotalSectors->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        m_LabelTextTotalSectors->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        gridLayout->addWidget(m_LabelTextTotalSectors, 6, 1, 1, 1);

        m_LabelTotalSize = new QLabel(VolumeGroupWidgetBase);
        m_LabelTotalSize->setObjectName("m_LabelTotalSize");
        m_LabelTotalSize->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        gridLayout->addWidget(m_LabelTotalSize, 4, 2, 1, 1);

        m_LabelTotalUsedSize = new QLabel(VolumeGroupWidgetBase);
        m_LabelTotalUsedSize->setObjectName("m_LabelTotalUsedSize");
        m_LabelTotalUsedSize->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        gridLayout->addWidget(m_LabelTotalUsedSize, 5, 2, 1, 1);

        m_LabelTextTotalUsedSize = new QLabel(VolumeGroupWidgetBase);
        m_LabelTextTotalUsedSize->setObjectName("m_LabelTextTotalUsedSize");
        m_LabelTextTotalUsedSize->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        m_LabelTextTotalUsedSize->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        gridLayout->addWidget(m_LabelTextTotalUsedSize, 5, 1, 1, 1);


        retranslateUi(VolumeGroupWidgetBase);

        QMetaObject::connectSlotsByName(VolumeGroupWidgetBase);
    } // setupUi

    void retranslateUi(QWidget *VolumeGroupWidgetBase)
    {
        m_LabelTextVGName->setText(tr2i18n("Volume Group Name: ", nullptr));
        m_LabelTextPESize->setText(tr2i18n("Physical Extent Size: ", nullptr));
        m_LabelTotalSectors->setText(tr2i18n("---", nullptr));
        m_SpinPESize->setSuffix(tr2i18n(" MiB", nullptr));
        m_LabelTextTotalLV->setText(tr2i18n("Total LV: ", nullptr));
        m_LabelTotalLV->setText(tr2i18n("---", nullptr));
        m_LabelTextVolumeType->setText(tr2i18n("Volume Group Type: ", nullptr));
        m_LabelTextTotalSize->setText(tr2i18n("Total Size: ", nullptr));
        m_LabelTextTotalSectors->setText(tr2i18n("Total Sectors: ", nullptr));
        m_LabelTotalSize->setText(tr2i18n("---", nullptr));
        m_LabelTotalUsedSize->setText(tr2i18n("---", nullptr));
        m_LabelTextTotalUsedSize->setText(tr2i18n("Used Size: ", nullptr));
        (void)VolumeGroupWidgetBase;
    } // retranslateUi

};

namespace Ui {
    class VolumeGroupWidgetBase: public Ui_VolumeGroupWidgetBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // VOLUMEGROUPWIDGETBASE_H

